@@ -2,7 +2,7 @@
  * Copyright (C) 2017-2019 Volker Kohaupt
  * 
  * Author:
- *      Volker Kohaupt <vkohaupt@freenet.de>
+ *      Volker Kohaupt <vkohaupt@volkoh.de>
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of version 2 of the GNU General Public License
@@ -216,7 +216,7 @@ void QvkGlobalShortcut::slot_checkbox_shortcut_start_clicked( bool value )
 
         QString shortcut;
         if ( ui->checkBox_shortcut_start_strg->isChecked() ) {
-            shortcut.append( "+STRG" );
+            shortcut.append( "+CTRL" );
         }
         if ( ui->checkBox_shortcut_start_shift->isChecked() ) {
             shortcut.append( "+SHIFT" );
@@ -240,6 +240,9 @@ void QvkGlobalShortcut::slot_checkbox_shortcut_start_clicked( bool value )
         ui->pushButtonStart->setToolTip( shortcut );
         ui->pushButtonStop->setToolTip( shortcut );
 
+        emit signal_shortcutSystray( "Start", shortcut );
+        emit signal_shortcutSystray( "Stop", shortcut );
+
         qDebug().noquote() << global::nameOutput << "Set global shortcut for Start:" << shortcut;
     } else
     {
@@ -250,6 +253,10 @@ void QvkGlobalShortcut::slot_checkbox_shortcut_start_clicked( bool value )
         shortcutStart->unsetShortcut();
         ui->pushButtonStart->setToolTip( "None" );
         ui->pushButtonStop->setToolTip( "None" );
+
+        emit signal_shortcutSystray( "Start", "None" );
+        emit signal_shortcutSystray( "Stop", "None" );
+
         qDebug().noquote() << global::nameOutput << "Set global shortcut for Start: None";
     }
 }
@@ -274,7 +281,7 @@ void QvkGlobalShortcut::slot_checkbox_shortcut_pause_clicked( bool value )
 
         QString shortcut;
         if ( ui->checkBox_shortcut_pause_strg->isChecked() ) {
-            shortcut.append( "+STRG" );
+            shortcut.append( "+CTRL" );
         }
         if ( ui->checkBox_shortcut_pause_shift->isChecked() ) {
             shortcut.append( "+SHIFT" );
@@ -298,6 +305,9 @@ void QvkGlobalShortcut::slot_checkbox_shortcut_pause_clicked( bool value )
         ui->pushButtonPause->setToolTip( shortcut );
         ui->pushButtonContinue->setToolTip( shortcut );
 
+        emit signal_shortcutSystray( "Pause", shortcut );
+        emit signal_shortcutSystray( "Continue", shortcut );
+
         qDebug().noquote() << global::nameOutput << "Set global shortcut for Pause:" << shortcut;
     } else
     {
@@ -308,6 +318,10 @@ void QvkGlobalShortcut::slot_checkbox_shortcut_pause_clicked( bool value )
         shortcutPause->unsetShortcut();
         ui->pushButtonPause->setToolTip( "None" );
         ui->pushButtonContinue->setToolTip( "None" );
+
+        emit signal_shortcutSystray( "Pause", "None" );
+        emit signal_shortcutSystray( "Continue", "None" );
+
         qDebug().noquote() << global::nameOutput << "Set global shortcut for Pause: None";
     }
 }
@@ -332,7 +346,7 @@ void QvkGlobalShortcut::slot_checkbox_shortcut_magnification_clicked( bool value
 
         QString shortcut;
         if ( ui->checkBox_shortcut_magnification_strg->isChecked() ) {
-            shortcut.append( "+STRG" );
+            shortcut.append( "+CTRL" );
         }
         if ( ui->checkBox_shortcut_magnification_shift->isChecked() ) {
             shortcut.append( "+SHIFT" );
@@ -352,23 +366,21 @@ void QvkGlobalShortcut::slot_checkbox_shortcut_magnification_clicked( bool value
 
         shortcutMagnification->unsetShortcut();
         shortcutMagnification->setShortcut( QKeySequence( shortcut ) );
-
         ui->checkBoxMagnifier->setToolTip( shortcut );
-
+        emit signal_shortcutSystray( "magnification", shortcut );
         qDebug().noquote() << global::nameOutput << "Set global shortcut for Magnification:" << shortcut;
     } else
     {
         QIcon iconAvailable( QString::fromUtf8( ":/pictures/screencast/missing.png" ) );
         QSize size = iconAvailable.actualSize( QSize( 16, 16 ), QIcon::Normal, QIcon::On );
         ui->label_shortcut_picture_magnification->setPixmap( iconAvailable.pixmap( size, QIcon::Normal, QIcon::On ));
-
         shortcutMagnification->unsetShortcut();
         ui->checkBoxMagnifier->setToolTip( "None" );
+        emit signal_shortcutSystray( "magnification", "None" );
         qDebug().noquote() << global::nameOutput << "Set global shortcut for Magnification: None";
     }
 }
 
-
 void QvkGlobalShortcut::slot_checkbox_shortcut_magnification_currentIndexChanged( int value )
 {
     Q_UNUSED(value)
@@ -389,7 +401,7 @@ void QvkGlobalShortcut::slot_checkbox_shortcut_camera_clicked( bool value )
 
         QString shortcut;
         if ( ui->checkBox_shortcut_camera_strg->isChecked() ) {
-            shortcut.append( "+STRG" );
+            shortcut.append( "+CTRL" );
         }
         if ( ui->checkBox_shortcut_camera_shift->isChecked() ) {
             shortcut.append( "+SHIFT" );
@@ -409,9 +421,8 @@ void QvkGlobalShortcut::slot_checkbox_shortcut_camera_clicked( bool value )
 
         shortcutCamera->unsetShortcut();
         shortcutCamera->setShortcut( QKeySequence( shortcut ) );
-
         ui->checkBoxCameraOnOff->setToolTip( shortcut );
-
+        emit signal_shortcutSystray( "camera", shortcut );
         qDebug().noquote() << global::nameOutput << "Set global shortcut for Camera:" << shortcut;
     } else
     {
@@ -421,6 +432,7 @@ void QvkGlobalShortcut::slot_checkbox_shortcut_camera_clicked( bool value )
 
         shortcutCamera->unsetShortcut();
         ui->checkBoxCameraOnOff->setToolTip( "None" );
+        emit signal_shortcutSystray( "camera", "None" );
         qDebug().noquote() << global::nameOutput << "Set global shortcut for Camera: None";
     }
 }
@@ -445,7 +457,7 @@ void QvkGlobalShortcut::slot_checkbox_shortcut_showclick_clicked( bool value )
 
         QString shortcut;
         if ( ui->checkBox_shortcut_showclick_strg->isChecked() ) {
-            shortcut.append( "+STRG" );
+            shortcut.append( "+CTRL" );
         }
         if ( ui->checkBox_shortcut_showclick_shift->isChecked() ) {
             shortcut.append( "+SHIFT" );
@@ -465,9 +477,8 @@ void QvkGlobalShortcut::slot_checkbox_shortcut_showclick_clicked( bool value )
 
         shortcutShowclick->unsetShortcut();
         shortcutShowclick->setShortcut( QKeySequence( shortcut ) );
-
         spezialCheckboxShowclick->setToolTip( shortcut );
-
+        emit signal_shortcutSystray( "showclick", shortcut );
         qDebug().noquote() << global::nameOutput << "Set global shortcut for Showclick:" << shortcut;
     } else
     {
@@ -477,6 +488,7 @@ void QvkGlobalShortcut::slot_checkbox_shortcut_showclick_clicked( bool value )
 
         shortcutShowclick->unsetShortcut();
         spezialCheckboxShowclick->setToolTip( "None" );
+        emit signal_shortcutSystray( "showclick", "None" );
         qDebug().noquote() << global::nameOutput << "Set global shortcut for Showclick: None";
     }
 }
@@ -501,7 +513,7 @@ void QvkGlobalShortcut::slot_checkbox_shortcut_halo_clicked( bool value )
 
         QString shortcut;
         if ( ui->checkBox_shortcut_halo_strg->isChecked() ) {
-            shortcut.append( "+STRG" );
+            shortcut.append( "+CTRL" );
         }
         if ( ui->checkBox_shortcut_halo_shift->isChecked() ) {
             shortcut.append( "+SHIFT" );
@@ -523,7 +535,7 @@ void QvkGlobalShortcut::slot_checkbox_shortcut_halo_clicked( bool value )
         shortcutHalo->setShortcut( QKeySequence( shortcut ) );
 
         spezialCheckboxHalo->setToolTip( shortcut );
-
+        emit signal_shortcutSystray( "halo", shortcut );
         qDebug().noquote() << global::nameOutput << "Set global shortcut for Halo:" << shortcut;
     } else
     {
@@ -533,6 +545,7 @@ void QvkGlobalShortcut::slot_checkbox_shortcut_halo_clicked( bool value )
 
         shortcutHalo->unsetShortcut();
         spezialCheckboxHalo->setToolTip( "None" );
+        emit signal_shortcutSystray( "halo", "None" );
         qDebug().noquote() << global::nameOutput << "Set global shortcut for Halo: None";
     }
 }
