@@ -2,7 +2,7 @@
  * Copyright (C) 2017-2019 Volker Kohaupt
  * 
  * Author:
- *      Volker Kohaupt <vkohaupt@freenet.de>
+ *      Volker Kohaupt <vkohaupt@volkoh.de>
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of version 2 of the GNU General Public License
@@ -38,37 +38,42 @@ class QvkCameraController : public QObject
     Q_OBJECT
 
 public:
-   QvkCameraController( Ui_formMainWindow *ui_surface );
-   virtual ~QvkCameraController();
+    QvkCameraController( Ui_formMainWindow *ui_surface );
+    virtual ~QvkCameraController();
+
+    QvkCameraWindow *cameraWindow;
+    void getAllDevices();
+    cameraSettingsDialog *vkCameraSettingsDialog;
+    Ui_cameraSettingsDialog *uiCameraSettingsDialog;
 
-   QvkCameraWindow *cameraWindow;
-   void getAllDevices();
 
-  
 public slots:
 
 
 private slots:
-   void slot_addedCamera( QString description, QString device );
-   void slot_removedCamera( QString device );
-   void slot_startCamera( bool value );
+    void slot_addedCamera( QString description, QString device );
+    void slot_removedCamera( QString device );
+    void slot_startCamera( bool value );
 
-   void slot_statusChanged( QCamera::Status status );
-   void slot_stateChanged( QCamera::State state );
-   void slot_error( QCamera::Error error );
+    void slot_statusChanged( QCamera::Status status );
+    void slot_stateChanged( QCamera::State state );
+    void slot_error( QCamera::Error error );
 
-   void slot_setNewImage( QImage image );
+    void slot_setNewImage( QImage image );
 
-   void slot_frameOnOff( bool value );
-   void slot_sliderMoved( int value );
+    void slot_frameOnOff( bool value );
+    void slot_sliderMoved( int value );
+
+    void slot_resolutionChanged();
 
 
 private:
-  Ui_formMainWindow *ui_formMainWindow;
-  QCamera *camera = nullptr;
-  QvkCameraWatcher *cameraWatcher;
-  QvkVideoSurface *videoSurface;
-  QvkSpezialSlider *sliderCameraWindowSize;
+    Ui_formMainWindow *ui_formMainWindow;
+    QCamera *camera = nullptr;
+    QvkCameraWatcher *cameraWatcher;
+    QvkVideoSurface *videoSurface;
+    QvkSpezialSlider *sliderCameraWindowSize;
+    QvkSpezialSlider *sliderCameraWindowZoom;
 
 protected:
 
