@@ -2,7 +2,7 @@
  * Copyright (C) 2017-2019 Volker Kohaupt
  * 
  * Author:
- *      Volker Kohaupt <vkohaupt@freenet.de>
+ *      Volker Kohaupt <vkohaupt@volkoh.de>
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of version 2 of the GNU General Public License
@@ -74,6 +74,7 @@ void QvkCameraResolution::slot_statusChanged( QCamera::Status status )
                            << ui_formMainWindow->comboBoxCamera->currentText()
                            << ui_formMainWindow->comboBoxCamera->currentData().toByteArray();
         qDebug() << resolution;
+
         camera->unload();
         disconnect( camera, nullptr, nullptr, nullptr );
 
@@ -84,6 +85,19 @@ void QvkCameraResolution::slot_statusChanged( QCamera::Status status )
         ui_formMainWindow->comboBoxCameraResolution->setCurrentIndex( index );
         vkCameraSettingsDialog->ui->comboBoxCameraResolution->setCurrentIndex( index );
 
+        QList<QSlider *> listSlider = ui_formMainWindow->centralWidget->findChildren<QSlider *>();
+        for ( int i = 0; i < listSlider.count(); i++ )
+        {
+            if ( ( listSlider.at(i)->objectName() == "sliderCameraWindowSize" ) or ( listSlider.at(i)->objectName() == "sliderCameraWindowZoom" ) )
+            {
+                QVariant variant = settings.value( listSlider.at(i)->objectName() );
+                if ( variant.isValid() )
+                {
+                    listSlider.at(i)->setValue( variant.toInt() );
+                }
+            }
+        }
+
         break;
     }// 4
     case QCamera::StandbyStatus     : { qDebug().noquote() << global::nameOutput << "QvkCameraResolution" << status; break; }// 5
