@@ -2,7 +2,7 @@
  * Copyright (C) 2017-2019 Volker Kohaupt
  * 
  * Author:
- *      Volker Kohaupt <vkohaupt@freenet.de>
+ *      Volker Kohaupt <vkohaupt@volkoh.de>
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of version 2 of the GNU General Public License
@@ -37,7 +37,7 @@ class QvkCameraWindow : public QLabel
     Q_OBJECT
 
 public:
-    QvkCameraWindow( Ui_formMainWindow *ui_surface, QvkSpezialSlider *gui_sliderCameraWindowSize, cameraSettingsDialog *settingsDialog);
+    QvkCameraWindow( Ui_formMainWindow *ui_surface, cameraSettingsDialog *settingsDialog);
     virtual ~QvkCameraWindow();
     Ui_cameraSettingsDialog *uiCameraSettingsDialog;
     cameraSettingsDialog *vkCameraSettingsDialog;
@@ -45,7 +45,9 @@ public:
 
 private:
    Ui_formMainWindow *ui_formMainWindow;
-
+   bool mousePressed = false;
+   int mouseLocal_X;
+   int mouseLocal_Y;
 
 public slots:
 
@@ -58,9 +60,10 @@ protected:
     void closeEvent(QCloseEvent *event);
     void mouseDoubleClickEvent( QMouseEvent *event );
     void keyPressEvent( QKeyEvent *event );
-
     void mousePressEvent(QMouseEvent *event);
     void resizeEvent(QResizeEvent *event);
+    void mouseReleaseEvent(QMouseEvent *event);
+    void mouseMoveEvent(QMouseEvent *event);
 
 signals:
     void signal_cameraWindow_close( bool );
