@@ -2,7 +2,7 @@
  * Copyright (C) 2017-2021 Volker Kohaupt
  *
  * Author:
- *      Volker Kohaupt <vkohaupt@freenet.de>
+ *      Volker Kohaupt <vkohaupt@volkoh.de>
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of version 2 of the GNU General Public License
@@ -100,9 +100,14 @@ void QvkCiscoOpenh264Controller::slot_downloadProgress( qint64 downloadedSize, q
 void QvkCiscoOpenh264Controller::slot_closeWaitDialog()
 {
     vkCiscoWaitDialog->close();
+
     ui->tabWidgetSideBar->show();
     ui->tabWidgetSideBar->repaint();
     ui->tabWidgetSideBar->update();
+
+    ui->widgetSidbar->show();
+    ui->widgetSidbar->repaint();
+    ui->widgetSidbar->update();
 }
 
 
