@@ -2,7 +2,7 @@
  * Copyright (C) 2017-2019 Volker Kohaupt
  * 
  * Author:
- *      Volker Kohaupt <vkohaupt@freenet.de>
+ *      Volker Kohaupt <vkohaupt@volkoh.de>
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of version 2 of the GNU General Public License
@@ -22,18 +22,20 @@
 
 #include "global.h"
 #include <QString>
+#include <QLineEdit>
 
 namespace global
 {
     QString name = "vokoscreenNG";
     QString nameOutput = "[" + name + "]";
     int showclickCounter = 0;
+    QLineEdit *lineEdit_EOS;
 
 #ifdef Q_OS_LINUX
-    QString version = "3.1.0";
+    QString version = "3.3.0";
 #endif
 
 #ifdef Q_OS_WIN
-    QString version = "3.1.0";
+    QString version = "3.3.0";
 #endif
 }
