@@ -2,7 +2,7 @@
  * Copyright (C) 2017-2019 Volker Kohaupt
  * 
  * Author:
- *      Volker Kohaupt <vkohaupt@freenet.de>
+ *      Volker Kohaupt <vkohaupt@volkoh.de>
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of version 2 of the GNU General Public License
@@ -21,6 +21,7 @@
  */
 
 #include <QString>
+#include <QLineEdit>
 
 namespace global
 {
@@ -28,4 +29,5 @@ namespace global
     extern QString nameOutput;
     extern QString version;
     extern int showclickCounter;
+    extern QLineEdit *lineEdit_EOS;
 }
