@@ -2,7 +2,7 @@
  * Copyright (C) 2017-2019 Volker Kohaupt
  * 
  * Author:
- *      Volker Kohaupt <vkohaupt@freenet.de>
+ *      Volker Kohaupt <vkohaupt@volkoh.de>
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of version 2 of the GNU General Public License
@@ -39,11 +39,12 @@ class QvkHelp: public QWidget
     Q_OBJECT
     
 public:
-    QvkHelp(QMainWindow *mainWindow, Ui_formMainWindow *ui_mainwindow);
+    QvkHelp( Ui_formMainWindow *ui_mainwindow );
     virtual ~QvkHelp() override;
     
 
 public slots:
+    void slot_cleanUp();
 
   
 private:
@@ -72,7 +73,6 @@ private slots:
     void slot_parseHTML( QString tempPathFileName );
     void slot_showHelp( QString tempPathFileName );
 
-    void slot_cleanUp();
     void slot_NetworkAccessibility( QNetworkAccessManager::NetworkAccessibility accessible );
 
     void slot_parse_locale( QStringList list );
