@@ -24,6 +24,21 @@
         <translation>Alterna a pantalla completa</translation>
     </message>
 </context>
+<context>
+    <name>QvkCiscoFinishDialog</name>
+    <message>
+        <source>The setup was successful.</source>
+        <translation>La configuració ha estat correcta.</translation>
+    </message>
+    <message>
+        <source>Close this window and start vokoscreenNG again.</source>
+        <translation>Tanca aquesta finestra i torna a iniciar el vokoscreenNG.</translation>
+    </message>
+    <message>
+        <source>Have fun with vokoscreenNG</source>
+        <translation>Divertiu-vos amb el vokoscreenNG</translation>
+    </message>
+</context>
 <context>
     <name>QvkDirectSoundController</name>
     <message>
@@ -125,6 +140,13 @@
         <translation>Àrea</translation>
     </message>
 </context>
+<context>
+    <name>QvkRegionChoise_wl</name>
+    <message>
+        <source>Area</source>
+        <translation>Àrea</translation>
+    </message>
+</context>
 <context>
     <name>QvkSystray</name>
     <message>
@@ -178,6 +200,14 @@
         <source>Exit</source>
         <translation>Surt</translation>
     </message>
+    <message>
+        <source>Camera</source>
+        <translation>Càmera</translation>
+    </message>
+    <message>
+        <source>Magnification</source>
+        <translation>Ampliació</translation>
+    </message>
 </context>
 <context>
     <name>cameraSettingsDialog</name>
@@ -209,22 +239,10 @@
         <source>Remove window frame</source>
         <translation>Elimina el marc de la finestra</translation>
     </message>
-    <message>
-        <source>160x120</source>
-        <translation>160x120</translation>
-    </message>
-    <message>
-        <source>320x240</source>
-        <translation>320x240</translation>
-    </message>
     <message>
         <source>Camera settings</source>
         <translation>Ajustaments de la càmera</translation>
     </message>
-    <message>
-        <source>640x480</source>
-        <translation>640x480</translation>
-    </message>
 </context>
 <context>
     <name>formMainWindow</name>
@@ -468,6 +486,42 @@
         <source>Log</source>
         <translation>Registre</translation>
     </message>
+    <message>
+        <source>Automatically</source>
+        <translation>Automàticament</translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation>Crea imatges de les pestanyes</translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation>Informació de la llicència</translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation>ACTIU</translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation>INACTIU</translation>
+    </message>
+    <message>
+        <source>Global keyboard shortcuts</source>
+        <translation>Dreceres de teclat globals</translation>
+    </message>
+    <message>
+        <source>Assigned shortcut keys.</source>
+        <translation>Tecles assignades com a drecera.</translation>
+    </message>
+    <message>
+        <source>Keyboard shortcut not assigned or assigned more than once.</source>
+        <translation>Drecera de teclat sense assignar o assignada més d&apos;una vegada.</translation>
+    </message>
+    <message>
+        <source>If it shows assigned but does not work, it is being used by another program.</source>
+        <translation>Si es mostra com assignada, però no funciona, es deu a que és emprada per un altre programa.</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
