@@ -24,6 +24,21 @@
         <translation>Přepnout na celou obrazovku</translation>
     </message>
 </context>
+<context>
+    <name>QvkCiscoFinishDialog</name>
+    <message>
+        <source>The setup was successful.</source>
+        <translation>Nastavení proběhlo úspěšně.</translation>
+    </message>
+    <message>
+        <source>Close this window and start vokoscreenNG again.</source>
+        <translation>Zavřít toto okno a znovu spustit vokoscreenNG.</translation>
+    </message>
+    <message>
+        <source>Have fun with vokoscreenNG</source>
+        <translation>Hezkou zábavu s vokoscreenNG</translation>
+    </message>
+</context>
 <context>
     <name>QvkDirectSoundController</name>
     <message>
@@ -125,6 +140,13 @@
         <translation>Výřez</translation>
     </message>
 </context>
+<context>
+    <name>QvkRegionChoise_wl</name>
+    <message>
+        <source>Area</source>
+        <translation>Výřez</translation>
+    </message>
+</context>
 <context>
     <name>QvkSystray</name>
     <message>
@@ -178,6 +200,14 @@
         <source>Exit</source>
         <translation>Odejít</translation>
     </message>
+    <message>
+        <source>Camera</source>
+        <translation>Kamera</translation>
+    </message>
+    <message>
+        <source>Magnification</source>
+        <translation>Zvětšení</translation>
+    </message>
 </context>
 <context>
     <name>cameraSettingsDialog</name>
@@ -209,22 +239,10 @@
         <source>Remove window frame</source>
         <translation>Odstranit rám okna</translation>
     </message>
-    <message>
-        <source>160x120</source>
-        <translation>160x120</translation>
-    </message>
-    <message>
-        <source>320x240</source>
-        <translation>320x240</translation>
-    </message>
     <message>
         <source>Camera settings</source>
         <translation>Nastavení kamery</translation>
     </message>
-    <message>
-        <source>640x480</source>
-        <translation>640x480</translation>
-    </message>
 </context>
 <context>
     <name>formMainWindow</name>
@@ -266,7 +284,7 @@
     </message>
     <message>
         <source>Frames</source>
-        <translation>Rámy</translation>
+        <translation>Snímky</translation>
     </message>
     <message>
         <source>Videocodec</source>
@@ -468,6 +486,42 @@
         <source>Log</source>
         <translation>Logy</translation>
     </message>
+    <message>
+        <source>Automatically</source>
+        <translation>Automaticky</translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation>Vytvořit snímky karet</translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation>Informace o licenci</translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation>Zapnuto</translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation>Vypnuto</translation>
+    </message>
+    <message>
+        <source>Global keyboard shortcuts</source>
+        <translation>Globální klávesové zkratky</translation>
+    </message>
+    <message>
+        <source>Assigned shortcut keys.</source>
+        <translation>Přiřazené klávesové zkratky.</translation>
+    </message>
+    <message>
+        <source>Keyboard shortcut not assigned or assigned more than once.</source>
+        <translation>Nepřiřazená nebo více než jednou přiřazená klávesová zkratka.</translation>
+    </message>
+    <message>
+        <source>If it shows assigned but does not work, it is being used by another program.</source>
+        <translation>Pokud je zobrazena jako přiřazená, ale nefunguje, používá ji jiný program.</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
@@ -500,11 +554,11 @@
     </message>
     <message>
         <source>Previous frame</source>
-        <translation>Předchozí okno</translation>
+        <translation>Předchozí snímek</translation>
     </message>
     <message>
         <source>Next frame</source>
-        <translation>Následující okno</translation>
+        <translation>Následující snímek</translation>
     </message>
     <message>
         <source>Mute</source>
