@@ -24,6 +24,21 @@
         <translation>Auf Vollbild umschalten</translation>
     </message>
 </context>
+<context>
+    <name>QvkCiscoFinishDialog</name>
+    <message>
+        <source>The setup was successful.</source>
+        <translation>Das Setup war erfolgreich.</translation>
+    </message>
+    <message>
+        <source>Close this window and start vokoscreenNG again.</source>
+        <translation>Schließe das Fenster und starte vokoscreenNG erneut.</translation>
+    </message>
+    <message>
+        <source>Have fun with vokoscreenNG</source>
+        <translation>Have fun with vokoscreenNG</translation>
+    </message>
+</context>
 <context>
     <name>QvkDirectSoundController</name>
     <message>
@@ -125,6 +140,13 @@
         <translation>Bereich</translation>
     </message>
 </context>
+<context>
+    <name>QvkRegionChoise_wl</name>
+    <message>
+        <source>Area</source>
+        <translation>Bereich</translation>
+    </message>
+</context>
 <context>
     <name>QvkSystray</name>
     <message>
@@ -178,6 +200,14 @@
         <source>Exit</source>
         <translation>Verlassen</translation>
     </message>
+    <message>
+        <source>Camera</source>
+        <translation>Kamera</translation>
+    </message>
+    <message>
+        <source>Magnification</source>
+        <translation>Lupe</translation>
+    </message>
 </context>
 <context>
     <name>cameraSettingsDialog</name>
@@ -209,22 +239,10 @@
         <source>Remove window frame</source>
         <translation>Fensterrahmen entfernen</translation>
     </message>
-    <message>
-        <source>160x120</source>
-        <translation>160x120</translation>
-    </message>
-    <message>
-        <source>320x240</source>
-        <translation>320x240</translation>
-    </message>
     <message>
         <source>Camera settings</source>
         <translation>Kameraeinstellungen</translation>
     </message>
-    <message>
-        <source>640x480</source>
-        <translation>640x480</translation>
-    </message>
 </context>
 <context>
     <name>formMainWindow</name>
@@ -468,6 +486,42 @@
         <source>Log</source>
         <translation>Log</translation>
     </message>
+    <message>
+        <source>Automatically</source>
+        <translation>Automatisch</translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation>Erstelle Bilder von Tabs</translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation>Lizenz Information</translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation>Ein</translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation>Aus</translation>
+    </message>
+    <message>
+        <source>Global keyboard shortcuts</source>
+        <translation>Globale Tastenkombinationen</translation>
+    </message>
+    <message>
+        <source>Assigned shortcut keys.</source>
+        <translation>Zugewiesene Tastenkombinationen.</translation>
+    </message>
+    <message>
+        <source>Keyboard shortcut not assigned or assigned more than once.</source>
+        <translation>Tastaturkürzel nicht zugewiesen oder mehrfach zugewiesen.</translation>
+    </message>
+    <message>
+        <source>If it shows assigned but does not work, it is being used by another program.</source>
+        <translation>Wenn es zugewiesen anzeigt, aber nicht funktioniert, wird es von einem anderen Programm verwendet.</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
