@@ -24,6 +24,21 @@
         <translation>Ir a pantalla completa</translation>
     </message>
 </context>
+<context>
+    <name>QvkCiscoFinishDialog</name>
+    <message>
+        <source>The setup was successful.</source>
+        <translation>Configuración finalizada correctamente</translation>
+    </message>
+    <message>
+        <source>Close this window and start vokoscreenNG again.</source>
+        <translation>Cierre la ventana e inicie vokoscreenNG de nuevo</translation>
+    </message>
+    <message>
+        <source>Have fun with vokoscreenNG</source>
+        <translation>Difrute con vokoscreenNG</translation>
+    </message>
+</context>
 <context>
     <name>QvkDirectSoundController</name>
     <message>
@@ -126,6 +141,13 @@
         <translation>Área</translation>
     </message>
 </context>
+<context>
+    <name>QvkRegionChoise_wl</name>
+    <message>
+        <source>Area</source>
+        <translation>Área</translation>
+    </message>
+</context>
 <context>
     <name>QvkSystray</name>
     <message>
@@ -179,6 +201,14 @@
         <source>Exit</source>
         <translation>Salir</translation>
     </message>
+    <message>
+        <source>Camera</source>
+        <translation>Cámara</translation>
+    </message>
+    <message>
+        <source>Magnification</source>
+        <translation>Ampliación</translation>
+    </message>
 </context>
 <context>
     <name>cameraSettingsDialog</name>
@@ -210,22 +240,10 @@
         <source>Remove window frame</source>
         <translation>Quitar marco de ventana</translation>
     </message>
-    <message>
-        <source>160x120</source>
-        <translation>160 × 120</translation>
-    </message>
-    <message>
-        <source>320x240</source>
-        <translation>320 × 240</translation>
-    </message>
     <message>
         <source>Camera settings</source>
         <translation>Configuración de cámara</translation>
     </message>
-    <message>
-        <source>640x480</source>
-        <translation>640 × 480</translation>
-    </message>
 </context>
 <context>
     <name>formMainWindow</name>
@@ -470,6 +488,42 @@
         <source>Log</source>
         <translation>Registro</translation>
     </message>
+    <message>
+        <source>Automatically</source>
+        <translation>Automáticamente</translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation>Crear imágenes de pestañas</translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation>Información sobre la Licencia</translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation>Encender</translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation>Apagar</translation>
+    </message>
+    <message>
+        <source>Global keyboard shortcuts</source>
+        <translation>Accesos directos de teclado</translation>
+    </message>
+    <message>
+        <source>Assigned shortcut keys.</source>
+        <translation>Acceso directo asignado</translation>
+    </message>
+    <message>
+        <source>Keyboard shortcut not assigned or assigned more than once.</source>
+        <translation>Acceso directo de teclado no asignado o asignado más de una vez</translation>
+    </message>
+    <message>
+        <source>If it shows assigned but does not work, it is being used by another program.</source>
+        <translation>Si aparece asignado pero no funciona, es que está siendo utilizado por otro programa</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
