@@ -24,6 +24,21 @@
         <translation>Vaihda koko näyttöön</translation>
     </message>
 </context>
+<context>
+    <name>QvkCiscoFinishDialog</name>
+    <message>
+        <source>The setup was successful.</source>
+        <translation>Asennus onnistui.</translation>
+    </message>
+    <message>
+        <source>Close this window and start vokoscreenNG again.</source>
+        <translation>Sulje ikkuna ja käynnistä vokoscreenNG uudelleen.</translation>
+    </message>
+    <message>
+        <source>Have fun with vokoscreenNG</source>
+        <translation>Pidä hauskaa vokoscreenNG:n parissa</translation>
+    </message>
+</context>
 <context>
     <name>QvkDirectSoundController</name>
     <message>
@@ -125,6 +140,13 @@
         <translation>Alue</translation>
     </message>
 </context>
+<context>
+    <name>QvkRegionChoise_wl</name>
+    <message>
+        <source>Area</source>
+        <translation>Alue</translation>
+    </message>
+</context>
 <context>
     <name>QvkSystray</name>
     <message>
@@ -178,6 +200,14 @@
         <source>Exit</source>
         <translation>Poistu</translation>
     </message>
+    <message>
+        <source>Camera</source>
+        <translation>Kamera</translation>
+    </message>
+    <message>
+        <source>Magnification</source>
+        <translation>Suurennus</translation>
+    </message>
 </context>
 <context>
     <name>cameraSettingsDialog</name>
@@ -209,22 +239,10 @@
         <source>Remove window frame</source>
         <translation>Poista ikkunakehys</translation>
     </message>
-    <message>
-        <source>160x120</source>
-        <translation>160x120</translation>
-    </message>
-    <message>
-        <source>320x240</source>
-        <translation>320x240</translation>
-    </message>
     <message>
         <source>Camera settings</source>
         <translation>Kameran asetukset</translation>
     </message>
-    <message>
-        <source>640x480</source>
-        <translation>640x480</translation>
-    </message>
 </context>
 <context>
     <name>formMainWindow</name>
@@ -468,6 +486,42 @@
         <source>Log</source>
         <translation>Loki</translation>
     </message>
+    <message>
+        <source>Automatically</source>
+        <translation>Automaattisesti</translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation>Luo kuvat välilehdistä</translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation>Lisenssitiedot</translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation>ON</translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation>POIS</translation>
+    </message>
+    <message>
+        <source>Global keyboard shortcuts</source>
+        <translation>Yleiset pikanäppäimet</translation>
+    </message>
+    <message>
+        <source>Assigned shortcut keys.</source>
+        <translation>Määritetyt pikanäppäimet.</translation>
+    </message>
+    <message>
+        <source>Keyboard shortcut not assigned or assigned more than once.</source>
+        <translation>Pikanäppäintä ei ole määritetty tai määritetty useammin kuin kerran.</translation>
+    </message>
+    <message>
+        <source>If it shows assigned but does not work, it is being used by another program.</source>
+        <translation>Jos näyttää määritystä, mutta ei toimi, se on toisen ohjelman käytössä.</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
