@@ -24,6 +24,21 @@
         <translation>Mode plein écran</translation>
     </message>
 </context>
+<context>
+    <name>QvkCiscoFinishDialog</name>
+    <message>
+        <source>The setup was successful.</source>
+        <translation>L&apos;installation a réussi.</translation>
+    </message>
+    <message>
+        <source>Close this window and start vokoscreenNG again.</source>
+        <translation>Fermer cette fenêtre et démarrer vokoscreenNG de nouveau.</translation>
+    </message>
+    <message>
+        <source>Have fun with vokoscreenNG</source>
+        <translation>Amusez-vous bien avec vokoscreenNG</translation>
+    </message>
+</context>
 <context>
     <name>QvkDirectSoundController</name>
     <message>
@@ -69,7 +84,7 @@
     </message>
     <message>
         <source>Megabyte</source>
-        <translation>Megabyte</translation>
+        <translation>Megaoctet</translation>
     </message>
     <message>
         <source>The recording was stopped, not enough free disk space.</source>
@@ -125,6 +140,13 @@
         <translation>Zone</translation>
     </message>
 </context>
+<context>
+    <name>QvkRegionChoise_wl</name>
+    <message>
+        <source>Area</source>
+        <translation>Définir une zone manuellement</translation>
+    </message>
+</context>
 <context>
     <name>QvkSystray</name>
     <message>
@@ -178,6 +200,14 @@
         <source>Exit</source>
         <translation>Sortir</translation>
     </message>
+    <message>
+        <source>Camera</source>
+        <translation>Caméra</translation>
+    </message>
+    <message>
+        <source>Magnification</source>
+        <translation>Agrandissement</translation>
+    </message>
 </context>
 <context>
     <name>cameraSettingsDialog</name>
@@ -209,22 +239,10 @@
         <source>Remove window frame</source>
         <translation>Supprimer le cadre de la fenêtre </translation>
     </message>
-    <message>
-        <source>160x120</source>
-        <translation>160x120</translation>
-    </message>
-    <message>
-        <source>320x240</source>
-        <translation>320x240</translation>
-    </message>
     <message>
         <source>Camera settings</source>
         <translation>Configuration caméra</translation>
     </message>
-    <message>
-        <source>640x480</source>
-        <translation>640x480</translation>
-    </message>
 </context>
 <context>
     <name>formMainWindow</name>
@@ -454,7 +472,7 @@
     </message>
     <message>
         <source>Megabyte</source>
-        <translation>Megabyte</translation>
+        <translation>Megaoctet</translation>
     </message>
     <message>
         <source>Screencast</source>
@@ -468,6 +486,42 @@
         <source>Log</source>
         <translation>Se connecter</translation>
     </message>
+    <message>
+        <source>Automatically</source>
+        <translation>Automatiquement</translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation>Créer des images d&apos;onglets</translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation>Informations sur la licence</translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation>ON</translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation>OFF</translation>
+    </message>
+    <message>
+        <source>Global keyboard shortcuts</source>
+        <translation>Raccourcis clavier globaux</translation>
+    </message>
+    <message>
+        <source>Assigned shortcut keys.</source>
+        <translation>Raccourcis clavier assignés.</translation>
+    </message>
+    <message>
+        <source>Keyboard shortcut not assigned or assigned more than once.</source>
+        <translation>Raccourcis clavier non assignés ou assignés plus d&apos;une fois.</translation>
+    </message>
+    <message>
+        <source>If it shows assigned but does not work, it is being used by another program.</source>
+        <translation>Si marqué comme assigné mais que cela ne fonctionne pas, il doit être utilisé par un autre programme.</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
