@@ -24,6 +24,21 @@
         <translation>Pindah ke Layar Penuh</translation>
     </message>
 </context>
+<context>
+    <name>QvkCiscoFinishDialog</name>
+    <message>
+        <source>The setup was successful.</source>
+        <translation>Persiapan program sukses.</translation>
+    </message>
+    <message>
+        <source>Close this window and start vokoscreenNG again.</source>
+        <translation>Tutup jendela dan mulai vokoscreenNG lagi.</translation>
+    </message>
+    <message>
+        <source>Have fun with vokoscreenNG</source>
+        <translation>Selamat bersenang-senang dengan vokoscreenNG</translation>
+    </message>
+</context>
 <context>
     <name>QvkDirectSoundController</name>
     <message>
@@ -42,11 +57,11 @@
     <name>QvkImageFromTabs</name>
     <message>
         <source>No filemanager found.</source>
-        <translation>Manajer erkas tidak ditemukan</translation>
+        <translation>Manajer berkas tidak ditemukan</translation>
     </message>
     <message>
         <source>Please install a filemanager.</source>
-        <translation>Mohon pasang sebuah manajer berkas</translation>
+        <translation>Mohon pasang manajer berkas</translation>
     </message>
 </context>
 <context>
@@ -125,6 +140,13 @@
         <translation>Daerah</translation>
     </message>
 </context>
+<context>
+    <name>QvkRegionChoise_wl</name>
+    <message>
+        <source>Area</source>
+        <translation>Daerah</translation>
+    </message>
+</context>
 <context>
     <name>QvkSystray</name>
     <message>
@@ -178,6 +200,14 @@
         <source>Exit</source>
         <translation>Keluar</translation>
     </message>
+    <message>
+        <source>Camera</source>
+        <translation>Kamera</translation>
+    </message>
+    <message>
+        <source>Magnification</source>
+        <translation>Pembesaran</translation>
+    </message>
 </context>
 <context>
     <name>cameraSettingsDialog</name>
@@ -209,22 +239,10 @@
         <source>Remove window frame</source>
         <translation>Hilangkan bingkai jendela</translation>
     </message>
-    <message>
-        <source>160x120</source>
-        <translation>160x120</translation>
-    </message>
-    <message>
-        <source>320x240</source>
-        <translation>320x240</translation>
-    </message>
     <message>
         <source>Camera settings</source>
         <translation>Pengaturan Kamera</translation>
     </message>
-    <message>
-        <source>640x480</source>
-        <translation>640x480</translation>
-    </message>
 </context>
 <context>
     <name>formMainWindow</name>
@@ -468,6 +486,42 @@
         <source>Log</source>
         <translation>CtatanLog</translation>
     </message>
+    <message>
+        <source>Automatically</source>
+        <translation>Otomatis</translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation>Buat gambar dari tab</translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation>Informasi lisensi</translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation>ON</translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation>OFF</translation>
+    </message>
+    <message>
+        <source>Global keyboard shortcuts</source>
+        <translation>Tombol pintas global</translation>
+    </message>
+    <message>
+        <source>Assigned shortcut keys.</source>
+        <translation>Tombol pintas yang diterapkan.</translation>
+    </message>
+    <message>
+        <source>Keyboard shortcut not assigned or assigned more than once.</source>
+        <translation>Tombol pintas belum dipasang atau telah dipasang lebih dari sekali.</translation>
+    </message>
+    <message>
+        <source>If it shows assigned but does not work, it is being used by another program.</source>
+        <translation>Apabila telah diterapkan namun tidak bekerja, bisa jadi sedang digunakan oleh program lain.</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
