@@ -17,11 +17,26 @@
     <name>QvkCameraWindow</name>
     <message>
         <source>Switch to Window</source>
-        <translation>Modalità finestra</translation>
+        <translation>Passa a Finestra</translation>
     </message>
     <message>
         <source>Switch to Fullscreen</source>
-        <translation>Modalità schermo intero</translation>
+        <translation>Passa a Schermo Intero</translation>
+    </message>
+</context>
+<context>
+    <name>QvkCiscoFinishDialog</name>
+    <message>
+        <source>The setup was successful.</source>
+        <translation>La configurazione ha avuto successo.</translation>
+    </message>
+    <message>
+        <source>Close this window and start vokoscreenNG again.</source>
+        <translation>Chiudere questa finestra e riavviare vokoscreenNG.</translation>
+    </message>
+    <message>
+        <source>Have fun with vokoscreenNG</source>
+        <translation>Buon divertimento con vokoscreenNG</translation>
     </message>
 </context>
 <context>
@@ -42,11 +57,11 @@
     <name>QvkImageFromTabs</name>
     <message>
         <source>No filemanager found.</source>
-        <translation>Filemanager non trovato</translation>
+        <translation>Nessun filemanager trovato.</translation>
     </message>
     <message>
         <source>Please install a filemanager.</source>
-        <translation>Si prega di installare un filemanager</translation>
+        <translation>Installa un filemanager.</translation>
     </message>
 </context>
 <context>
@@ -57,7 +72,7 @@
     </message>
     <message>
         <source>The recording is not started, not enough free disk space.</source>
-        <translation>La registrazione non è partita, spazio disco insufficiente</translation>
+        <translation>Registrazione non è stata avviata. Spazio disco insufficiente.</translation>
     </message>
     <message>
         <source>The free disk space limit is reached.</source>
@@ -73,7 +88,7 @@
     </message>
     <message>
         <source>The recording was stopped, not enough free disk space.</source>
-        <translation>Registrazione interrotta, spazio disco insufficiente</translation>
+        <translation>Registrazione interrotta. Spazio disco insufficiente</translation>
     </message>
 </context>
 <context>
@@ -88,11 +103,11 @@
     </message>
     <message>
         <source>No filemanager found.</source>
-        <translation>Filemanager non trovato</translation>
+        <translation>Filemanager non trovato.</translation>
     </message>
     <message>
         <source>Please install a filemanager.</source>
-        <translation>Si prega di installare un filemanager</translation>
+        <translation>Si prega di installare un filemanager.</translation>
     </message>
     <message>
         <source>Sourcecode</source>
@@ -125,11 +140,18 @@
         <translation>Area</translation>
     </message>
 </context>
+<context>
+    <name>QvkRegionChoise_wl</name>
+    <message>
+        <source>Area</source>
+        <translation>Area</translation>
+    </message>
+</context>
 <context>
     <name>QvkSystray</name>
     <message>
         <source>Start</source>
-        <translation>Avvia</translation>
+        <translation>Inizia</translation>
     </message>
     <message>
         <source>Stop</source>
@@ -160,11 +182,11 @@
     <name>QvkSystrayAlternative</name>
     <message>
         <source>Start</source>
-        <translation>Avvia</translation>
+        <translation>Inizia</translation>
     </message>
     <message>
         <source>Stop</source>
-        <translation>Ferma</translation>
+        <translation>Interrompi</translation>
     </message>
     <message>
         <source>Pause</source>
@@ -178,6 +200,14 @@
         <source>Exit</source>
         <translation>Esci</translation>
     </message>
+    <message>
+        <source>Camera</source>
+        <translation>Webcam</translation>
+    </message>
+    <message>
+        <source>Magnification</source>
+        <translation>Ingrandisci</translation>
+    </message>
 </context>
 <context>
     <name>cameraSettingsDialog</name>
@@ -187,11 +217,11 @@
     </message>
     <message>
         <source>Flip horizontal</source>
-        <translation>Ribalta orizzontalmente</translation>
+        <translation>Capovolgi orizzontale</translation>
     </message>
     <message>
         <source>Flip vertical</source>
-        <translation>Ribalta verticalmente</translation>
+        <translation>Capovolgi verticale</translation>
     </message>
     <message>
         <source>Invert</source>
@@ -209,22 +239,10 @@
         <source>Remove window frame</source>
         <translation>Rimuovi bordo finestra</translation>
     </message>
-    <message>
-        <source>160x120</source>
-        <translation>160x120</translation>
-    </message>
-    <message>
-        <source>320x240</source>
-        <translation>320x240</translation>
-    </message>
     <message>
         <source>Camera settings</source>
         <translation>Impostazioni camera</translation>
     </message>
-    <message>
-        <source>640x480</source>
-        <translation>640x480</translation>
-    </message>
 </context>
 <context>
     <name>formMainWindow</name>
@@ -238,11 +256,11 @@
     </message>
     <message>
         <source>Magnification</source>
-        <translation>Ingrandimento</translation>
+        <translation>Ingrandisci</translation>
     </message>
     <message>
         <source>Countdown</source>
-        <translation>Ritarda avvio</translation>
+        <translation>Avvio ritardo di</translation>
     </message>
     <message>
         <source>Video size:</source>
@@ -258,7 +276,7 @@
     </message>
     <message>
         <source>Record Time:</source>
-        <translation>Ora di registrazione:</translation>
+        <translation>Tempo di registrazione:</translation>
     </message>
     <message>
         <source>Audio</source>
@@ -270,11 +288,11 @@
     </message>
     <message>
         <source>Videocodec</source>
-        <translation>Codificatore video</translation>
+        <translation>Codifica video</translation>
     </message>
     <message>
         <source>Format</source>
-        <translation>Formato</translation>
+        <translation>Formato video</translation>
     </message>
     <message>
         <source>Audiocodec</source>
@@ -298,7 +316,7 @@
     </message>
     <message>
         <source>Start the timer</source>
-        <translation>Avvia il timer</translation>
+        <translation>Avvia il tempo</translation>
     </message>
     <message>
         <source>Stop recording after</source>
@@ -418,19 +436,19 @@
     </message>
     <message>
         <source>Minimized when recording starts</source>
-        <translation>Minimizza all&apos;attivazione della registrazione</translation>
+        <translation>Ridotto a icona durante la registrazione</translation>
     </message>
     <message>
         <source>Starts minimized</source>
-        <translation>Avvia minimizzato</translation>
+        <translation>Avvia a icona</translation>
     </message>
     <message>
         <source>Flip horizontal</source>
-        <translation>Ribalta orizzontalmente</translation>
+        <translation>Capovolgi orizzontale</translation>
     </message>
     <message>
         <source>Flip vertical</source>
-        <translation>Ribalta verticalmente</translation>
+        <translation>Capovolgi verticale</translation>
     </message>
     <message>
         <source>Black-and-white</source>
@@ -458,7 +476,7 @@
     </message>
     <message>
         <source>Screencast</source>
-        <translation>Trasmissione schermo</translation>
+        <translation>Registra Schermo</translation>
     </message>
     <message>
         <source>Player</source>
@@ -466,7 +484,43 @@
     </message>
     <message>
         <source>Log</source>
-        <translation>Registro</translation>
+        <translation>Registro eventi</translation>
+    </message>
+    <message>
+        <source>Automatically</source>
+        <translation>Automaticamente</translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation>Crea immagini delle schede</translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation>Informazioni sulla licenza</translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation>Acceso</translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation>Spento</translation>
+    </message>
+    <message>
+        <source>Global keyboard shortcuts</source>
+        <translation>Scorciatoie da tastiera globali</translation>
+    </message>
+    <message>
+        <source>Assigned shortcut keys.</source>
+        <translation>Tasti scorciatoia assegnati.</translation>
+    </message>
+    <message>
+        <source>Keyboard shortcut not assigned or assigned more than once.</source>
+        <translation>Scorciatoia da tastiera non assegnata o assegnata più volte.</translation>
+    </message>
+    <message>
+        <source>If it shows assigned but does not work, it is being used by another program.</source>
+        <translation>Se mostra l&apos;assegnamento ma non funziona, significa che è usata da qualche altro programma.</translation>
     </message>
 </context>
 <context>
@@ -508,7 +562,7 @@
     </message>
     <message>
         <source>Mute</source>
-        <translation>Silenzioso</translation>
+        <translation>Silenzia</translation>
     </message>
     <message>
         <source>Move menu</source>
