@@ -24,6 +24,21 @@
         <translation>Perjungti į visą ekraną</translation>
     </message>
 </context>
+<context>
+    <name>QvkCiscoFinishDialog</name>
+    <message>
+        <source>The setup was successful.</source>
+        <translation>Sąranka buvo sėkminga.</translation>
+    </message>
+    <message>
+        <source>Close this window and start vokoscreenNG again.</source>
+        <translation>Užverkite šį langą ir dar kartą paleiskite vokoscreenNG.</translation>
+    </message>
+    <message>
+        <source>Have fun with vokoscreenNG</source>
+        <translation>Gero laiko su vokoscreenNG</translation>
+    </message>
+</context>
 <context>
     <name>QvkDirectSoundController</name>
     <message>
@@ -125,6 +140,13 @@
         <translation>Sritis</translation>
     </message>
 </context>
+<context>
+    <name>QvkRegionChoise_wl</name>
+    <message>
+        <source>Area</source>
+        <translation>Sritis</translation>
+    </message>
+</context>
 <context>
     <name>QvkSystray</name>
     <message>
@@ -178,6 +200,14 @@
         <source>Exit</source>
         <translation>Išeiti</translation>
     </message>
+    <message>
+        <source>Camera</source>
+        <translation>Kamera</translation>
+    </message>
+    <message>
+        <source>Magnification</source>
+        <translation>Didinimas</translation>
+    </message>
 </context>
 <context>
     <name>cameraSettingsDialog</name>
@@ -209,22 +239,10 @@
         <source>Remove window frame</source>
         <translation>Šalinti lango rėmelį</translation>
     </message>
-    <message>
-        <source>160x120</source>
-        <translation>160x120</translation>
-    </message>
-    <message>
-        <source>320x240</source>
-        <translation>320x240</translation>
-    </message>
     <message>
         <source>Camera settings</source>
         <translation>Kameros nustatymai</translation>
     </message>
-    <message>
-        <source>640x480</source>
-        <translation>640x480</translation>
-    </message>
 </context>
 <context>
     <name>formMainWindow</name>
@@ -468,6 +486,42 @@
         <source>Log</source>
         <translation>Žurnalas</translation>
     </message>
+    <message>
+        <source>Automatically</source>
+        <translation>Automatiškai</translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation>Sukurti kortelių paveikslus</translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation>Informacija apie licenciją</translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation>ĮJUNGTA</translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation>IŠJUNGTA</translation>
+    </message>
+    <message>
+        <source>Global keyboard shortcuts</source>
+        <translation>Visuotiniai spartieji klavišai</translation>
+    </message>
+    <message>
+        <source>Assigned shortcut keys.</source>
+        <translation>Spartieji klavišai priskirti.</translation>
+    </message>
+    <message>
+        <source>Keyboard shortcut not assigned or assigned more than once.</source>
+        <translation>Spartusis klavišas nepriskirtas arba priskirtas daugiau kaip vieną kartą.</translation>
+    </message>
+    <message>
+        <source>If it shows assigned but does not work, it is being used by another program.</source>
+        <translation>Jei yra rodoma, jog jis yra priskirtas, o jis neveikia, vadinasi jį naudoja kita programa.</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
