@@ -21,7 +21,22 @@
     </message>
     <message>
         <source>Switch to Fullscreen</source>
-        <translation>Beeldvullende weergave</translation>
+        <translation>Schermvullende weergave</translation>
+    </message>
+</context>
+<context>
+    <name>QvkCiscoFinishDialog</name>
+    <message>
+        <source>The setup was successful.</source>
+        <translation>Het instellen is voltooid.</translation>
+    </message>
+    <message>
+        <source>Close this window and start vokoscreenNG again.</source>
+        <translation>Sluit dit venster en herstart vokoscreenNG.</translation>
+    </message>
+    <message>
+        <source>Have fun with vokoscreenNG</source>
+        <translation>Veel plezier met vokoscreenNG</translation>
     </message>
 </context>
 <context>
@@ -125,6 +140,13 @@
         <translation>Gebied</translation>
     </message>
 </context>
+<context>
+    <name>QvkRegionChoise_wl</name>
+    <message>
+        <source>Area</source>
+        <translation>Gebied</translation>
+    </message>
+</context>
 <context>
     <name>QvkSystray</name>
     <message>
@@ -178,6 +200,14 @@
         <source>Exit</source>
         <translation>Afsluiten</translation>
     </message>
+    <message>
+        <source>Camera</source>
+        <translation>Camera</translation>
+    </message>
+    <message>
+        <source>Magnification</source>
+        <translation>Vergroting</translation>
+    </message>
 </context>
 <context>
     <name>cameraSettingsDialog</name>
@@ -209,22 +239,10 @@
         <source>Remove window frame</source>
         <translation>Vensterrand verwijderen</translation>
     </message>
-    <message>
-        <source>160x120</source>
-        <translation>160x120</translation>
-    </message>
-    <message>
-        <source>320x240</source>
-        <translation>320x240</translation>
-    </message>
     <message>
         <source>Camera settings</source>
         <translation>Camera-instellingen</translation>
     </message>
-    <message>
-        <source>640x480</source>
-        <translation>640x480</translation>
-    </message>
 </context>
 <context>
     <name>formMainWindow</name>
@@ -418,7 +436,7 @@
     </message>
     <message>
         <source>Minimized when recording starts</source>
-        <translation>Minimaliseren als opname start</translation>
+        <translation>Minimaliseren zodra opname start</translation>
     </message>
     <message>
         <source>Starts minimized</source>
@@ -468,6 +486,42 @@
         <source>Log</source>
         <translation>Logboek</translation>
     </message>
+    <message>
+        <source>Automatically</source>
+        <translation>Automatisch</translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation>Afbeeldingen maken van tabbladen</translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation>Licentie-informatie</translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation>AAN</translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation>UIT</translation>
+    </message>
+    <message>
+        <source>Global keyboard shortcuts</source>
+        <translation>Globale sneltoetsen</translation>
+    </message>
+    <message>
+        <source>Assigned shortcut keys.</source>
+        <translation>De sneltoetsen zijn toegewezen.</translation>
+    </message>
+    <message>
+        <source>Keyboard shortcut not assigned or assigned more than once.</source>
+        <translation>De sneltoets is niet of meer dan eens toegewezen.</translation>
+    </message>
+    <message>
+        <source>If it shows assigned but does not work, it is being used by another program.</source>
+        <translation>Als de sneltoets wordt aangeduid als toegewezen maar niet werkt, dan is de sneltoets reeds in gebruik door een ander programma.</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
@@ -496,7 +550,7 @@
     </message>
     <message>
         <source>Fullscreen</source>
-        <translation>Beeldvullend</translation>
+        <translation>Schermvullend</translation>
     </message>
     <message>
         <source>Previous frame</source>
