@@ -24,6 +24,21 @@
         <translation>Bytt til fullskjerm</translation>
     </message>
 </context>
+<context>
+    <name>QvkCiscoFinishDialog</name>
+    <message>
+        <source>The setup was successful.</source>
+        <translation>Oppsettet var vellykket.</translation>
+    </message>
+    <message>
+        <source>Close this window and start vokoscreenNG again.</source>
+        <translation>Lukk dette vinduet og start vokoscreenNG på nytt.</translation>
+    </message>
+    <message>
+        <source>Have fun with vokoscreenNG</source>
+        <translation>Ha det gøy med vokoscreenNG</translation>
+    </message>
+</context>
 <context>
     <name>QvkDirectSoundController</name>
     <message>
@@ -125,6 +140,13 @@
         <translation>Område</translation>
     </message>
 </context>
+<context>
+    <name>QvkRegionChoise_wl</name>
+    <message>
+        <source>Area</source>
+        <translation>Område</translation>
+    </message>
+</context>
 <context>
     <name>QvkSystray</name>
     <message>
@@ -141,7 +163,7 @@
     </message>
     <message>
         <source>Continue</source>
-        <translation>Forsett</translation>
+        <translation>Fortsett</translation>
     </message>
     <message>
         <source>Exit</source>
@@ -172,12 +194,20 @@
     </message>
     <message>
         <source>Continue</source>
-        <translation>Forsett</translation>
+        <translation>Fortsett</translation>
     </message>
     <message>
         <source>Exit</source>
         <translation>Avslutt</translation>
     </message>
+    <message>
+        <source>Camera</source>
+        <translation>Kamera</translation>
+    </message>
+    <message>
+        <source>Magnification</source>
+        <translation>Forstørrelse</translation>
+    </message>
 </context>
 <context>
     <name>cameraSettingsDialog</name>
@@ -209,22 +239,10 @@
         <source>Remove window frame</source>
         <translation>Fjern vindusramme</translation>
     </message>
-    <message>
-        <source>160x120</source>
-        <translation>160x120</translation>
-    </message>
-    <message>
-        <source>320x240</source>
-        <translation>320x240</translation>
-    </message>
     <message>
         <source>Camera settings</source>
         <translation>Kamera instillinger</translation>
     </message>
-    <message>
-        <source>640x480</source>
-        <translation>640x480</translation>
-    </message>
 </context>
 <context>
     <name>formMainWindow</name>
@@ -286,7 +304,7 @@
     </message>
     <message>
         <source>Do not record mouse cursor</source>
-        <translation>ikke ta opp muse courser</translation>
+        <translation>ikke ta opp musepeker</translation>
     </message>
     <message>
         <source>Hour</source>
@@ -366,7 +384,7 @@
     </message>
     <message>
         <source>Continue</source>
-        <translation>Forsett</translation>
+        <translation>Fortsett</translation>
     </message>
     <message>
         <source>Play</source>
@@ -446,7 +464,7 @@
     </message>
     <message>
         <source>Reset all settings at the next start</source>
-        <translation>Nullstille alle innstillinger ved neste oppstart.</translation>
+        <translation>Nullstille alle innstillinger ved neste oppstart</translation>
     </message>
     <message>
         <source>Copyright and license from pictures</source>
@@ -468,6 +486,42 @@
         <source>Log</source>
         <translation>Logg</translation>
     </message>
+    <message>
+        <source>Automatically</source>
+        <translation>Automatisk</translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation>Lag bilder av faner</translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation>Lisensinformasjon</translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation>PÅ</translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation>AV</translation>
+    </message>
+    <message>
+        <source>Global keyboard shortcuts</source>
+        <translation>Globale tastatur snarveier</translation>
+    </message>
+    <message>
+        <source>Assigned shortcut keys.</source>
+        <translation>Tildelte snarvei taster.</translation>
+    </message>
+    <message>
+        <source>Keyboard shortcut not assigned or assigned more than once.</source>
+        <translation>Tastesnarvei ikke tildelt eller tildelt mer enn en gang.</translation>
+    </message>
+    <message>
+        <source>If it shows assigned but does not work, it is being used by another program.</source>
+        <translation>Hvis den vises som tildelt, men ikke virker, er den i bruk av et annet program.</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
