@@ -24,6 +24,21 @@
         <translation>Tryb pełnoekranowy</translation>
     </message>
 </context>
+<context>
+    <name>QvkCiscoFinishDialog</name>
+    <message>
+        <source>The setup was successful.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Close this window and start vokoscreenNG again.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Have fun with vokoscreenNG</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>QvkDirectSoundController</name>
     <message>
@@ -125,6 +140,13 @@
         <translation>Obszar</translation>
     </message>
 </context>
+<context>
+    <name>QvkRegionChoise_wl</name>
+    <message>
+        <source>Area</source>
+        <translation>Obszar</translation>
+    </message>
+</context>
 <context>
     <name>QvkSystray</name>
     <message>
@@ -178,6 +200,14 @@
         <source>Exit</source>
         <translation>Zakończ</translation>
     </message>
+    <message>
+        <source>Camera</source>
+        <translation>Kamera</translation>
+    </message>
+    <message>
+        <source>Magnification</source>
+        <translation>Powiększenie</translation>
+    </message>
 </context>
 <context>
     <name>cameraSettingsDialog</name>
@@ -209,22 +239,10 @@
         <source>Remove window frame</source>
         <translation>Usuń ramkę okna</translation>
     </message>
-    <message>
-        <source>160x120</source>
-        <translation>160x120</translation>
-    </message>
-    <message>
-        <source>320x240</source>
-        <translation>320x240</translation>
-    </message>
     <message>
         <source>Camera settings</source>
         <translation>Ustawienia kamery</translation>
     </message>
-    <message>
-        <source>640x480</source>
-        <translation>640x480</translation>
-    </message>
 </context>
 <context>
     <name>formMainWindow</name>
@@ -468,6 +486,42 @@
         <source>Log</source>
         <translation>Log</translation>
     </message>
+    <message>
+        <source>Automatically</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Global keyboard shortcuts</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Assigned shortcut keys.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Keyboard shortcut not assigned or assigned more than once.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>If it shows assigned but does not work, it is being used by another program.</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>license</name>
