@@ -24,6 +24,21 @@
         <translation>Mudar para ecrã inteiro</translation>
     </message>
 </context>
+<context>
+    <name>QvkCiscoFinishDialog</name>
+    <message>
+        <source>The setup was successful.</source>
+        <translation>A configuração foi bem sucedida.</translation>
+    </message>
+    <message>
+        <source>Close this window and start vokoscreenNG again.</source>
+        <translation>Feche esta janela e inicie vokoscreenNG novamente.</translation>
+    </message>
+    <message>
+        <source>Have fun with vokoscreenNG</source>
+        <translation>Divirta-se com vokoscreenNG</translation>
+    </message>
+</context>
 <context>
     <name>QvkDirectSoundController</name>
     <message>
@@ -125,6 +140,13 @@
         <translation>Área</translation>
     </message>
 </context>
+<context>
+    <name>QvkRegionChoise_wl</name>
+    <message>
+        <source>Area</source>
+        <translation>Área</translation>
+    </message>
+</context>
 <context>
     <name>QvkSystray</name>
     <message>
@@ -178,6 +200,14 @@
         <source>Exit</source>
         <translation>Sair</translation>
     </message>
+    <message>
+        <source>Camera</source>
+        <translation>Camera</translation>
+    </message>
+    <message>
+        <source>Magnification</source>
+        <translation>Ampliação</translation>
+    </message>
 </context>
 <context>
     <name>cameraSettingsDialog</name>
@@ -209,22 +239,10 @@
         <source>Remove window frame</source>
         <translation>Remover a moldura da janela</translation>
     </message>
-    <message>
-        <source>160x120</source>
-        <translation>160x120</translation>
-    </message>
-    <message>
-        <source>320x240</source>
-        <translation>320x240</translation>
-    </message>
     <message>
         <source>Camera settings</source>
         <translation>Configurações da câmara</translation>
     </message>
-    <message>
-        <source>640x480</source>
-        <translation>640x480</translation>
-    </message>
 </context>
 <context>
     <name>formMainWindow</name>
@@ -468,6 +486,42 @@
         <source>Log</source>
         <translation>Registos</translation>
     </message>
+    <message>
+        <source>Automatically</source>
+        <translation>Automaticamente</translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation>Criar imagens de guias</translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation>Informação de licença</translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation>ON</translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation>OFF</translation>
+    </message>
+    <message>
+        <source>Global keyboard shortcuts</source>
+        <translation>Atalhos globais de teclado</translation>
+    </message>
+    <message>
+        <source>Assigned shortcut keys.</source>
+        <translation>Teclas de atalho atribuídas.</translation>
+    </message>
+    <message>
+        <source>Keyboard shortcut not assigned or assigned more than once.</source>
+        <translation>Atalho de teclado não atribuído ou atribuído mais de uma vez.</translation>
+    </message>
+    <message>
+        <source>If it shows assigned but does not work, it is being used by another program.</source>
+        <translation>Se mostrar atribuído, mas não funciona, ele está sendo usado por outro programa.</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
