@@ -17,11 +17,26 @@
     <name>QvkCameraWindow</name>
     <message>
         <source>Switch to Window</source>
-        <translation>Mudar para janela</translation>
+        <translation>Mudar para Janela</translation>
     </message>
     <message>
         <source>Switch to Fullscreen</source>
-        <translation>Mudar para tela cheia</translation>
+        <translation>Mudar para o Modo Tela Cheia</translation>
+    </message>
+</context>
+<context>
+    <name>QvkCiscoFinishDialog</name>
+    <message>
+        <source>The setup was successful.</source>
+        <translation>Instalação concluída com sucesso.</translation>
+    </message>
+    <message>
+        <source>Close this window and start vokoscreenNG again.</source>
+        <translation>Feche esta Janela e Inicie o vokoscreenNG novamente.</translation>
+    </message>
+    <message>
+        <source>Have fun with vokoscreenNG</source>
+        <translation>Divirta-se com o vokoscreenNG!</translation>
     </message>
 </context>
 <context>
@@ -125,6 +140,13 @@
         <translation>Área</translation>
     </message>
 </context>
+<context>
+    <name>QvkRegionChoise_wl</name>
+    <message>
+        <source>Area</source>
+        <translation>Área</translation>
+    </message>
+</context>
 <context>
     <name>QvkSystray</name>
     <message>
@@ -178,6 +200,14 @@
         <source>Exit</source>
         <translation>Sair</translation>
     </message>
+    <message>
+        <source>Camera</source>
+        <translation>Câmera</translation>
+    </message>
+    <message>
+        <source>Magnification</source>
+        <translation>Zoom</translation>
+    </message>
 </context>
 <context>
     <name>cameraSettingsDialog</name>
@@ -209,22 +239,10 @@
         <source>Remove window frame</source>
         <translation>Remover moldura da janela</translation>
     </message>
-    <message>
-        <source>160x120</source>
-        <translation>160x120</translation>
-    </message>
-    <message>
-        <source>320x240</source>
-        <translation>320x240</translation>
-    </message>
     <message>
         <source>Camera settings</source>
         <translation>Configurações da câmera</translation>
     </message>
-    <message>
-        <source>640x480</source>
-        <translation>640x480</translation>
-    </message>
 </context>
 <context>
     <name>formMainWindow</name>
@@ -250,7 +268,7 @@
     </message>
     <message>
         <source>Free disk space:</source>
-        <translation>Espaço disponível no disco</translation>
+        <translation>Espaço disponível no disco:</translation>
     </message>
     <message>
         <source>Information</source>
@@ -266,7 +284,7 @@
     </message>
     <message>
         <source>Frames</source>
-        <translation>Frames</translation>
+        <translation>Quadros</translation>
     </message>
     <message>
         <source>Videocodec</source>
@@ -406,7 +424,7 @@
     </message>
     <message>
         <source>Play last record</source>
-        <translation>Reproduzir última gravação</translation>
+        <translation>Reproduzir a última gravação</translation>
     </message>
     <message>
         <source>Open folder</source>
@@ -468,6 +486,42 @@
         <source>Log</source>
         <translation>Log</translation>
     </message>
+    <message>
+        <source>Automatically</source>
+        <translation>Automaticamente</translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation>Criar imagens das abas</translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation>Infomações de Licença</translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation>LIGADO</translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation>DESLIGADO</translation>
+    </message>
+    <message>
+        <source>Global keyboard shortcuts</source>
+        <translation>Atalhos de teclado globais</translation>
+    </message>
+    <message>
+        <source>Assigned shortcut keys.</source>
+        <translation>Atalhos de teclado atribuídos</translation>
+    </message>
+    <message>
+        <source>Keyboard shortcut not assigned or assigned more than once.</source>
+        <translation>Atalho de teclado não atribuído ou atribuído em duplicidade.</translation>
+    </message>
+    <message>
+        <source>If it shows assigned but does not work, it is being used by another program.</source>
+        <translation>Se o atalho foi atribuído, mas não funciona, ele pode estar sendo utilizado por outro programa.</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
