@@ -24,6 +24,21 @@
         <translation>Переключиться в полноэкранный режим</translation>
     </message>
 </context>
+<context>
+    <name>QvkCiscoFinishDialog</name>
+    <message>
+        <source>The setup was successful.</source>
+        <translation>Установка завершена успешно.</translation>
+    </message>
+    <message>
+        <source>Close this window and start vokoscreenNG again.</source>
+        <translation>Закройте это окно и снова запустите vokoscreenNG.</translation>
+    </message>
+    <message>
+        <source>Have fun with vokoscreenNG</source>
+        <translation>Получайте удовольствие от vokoscreenNG</translation>
+    </message>
+</context>
 <context>
     <name>QvkDirectSoundController</name>
     <message>
@@ -42,7 +57,7 @@
     <name>QvkImageFromTabs</name>
     <message>
         <source>No filemanager found.</source>
-        <translation>Файлового менеджера не найдено.</translation>
+        <translation>Файловый менеджер не найден.</translation>
     </message>
     <message>
         <source>Please install a filemanager.</source>
@@ -57,11 +72,11 @@
     </message>
     <message>
         <source>The recording is not started, not enough free disk space.</source>
-        <translation>Запись не начата, недостаточно свободного места на диске.</translation>
+        <translation>Запись не началась, недостаточно свободного места на диске.</translation>
     </message>
     <message>
         <source>The free disk space limit is reached.</source>
-        <translation>Достигнут лимит свободного места на диске.</translation>
+        <translation>Достигнут предел свободного дискового пространства.</translation>
     </message>
     <message>
         <source>Limit of free disk space</source>
@@ -88,7 +103,7 @@
     </message>
     <message>
         <source>No filemanager found.</source>
-        <translation>Файлового менеджера не найдено.</translation>
+        <translation>Файловый менеджер не найден.</translation>
     </message>
     <message>
         <source>Please install a filemanager.</source>
@@ -125,6 +140,13 @@
         <translation>Область экрана</translation>
     </message>
 </context>
+<context>
+    <name>QvkRegionChoise_wl</name>
+    <message>
+        <source>Area</source>
+        <translation>Область экрана</translation>
+    </message>
+</context>
 <context>
     <name>QvkSystray</name>
     <message>
@@ -178,6 +200,14 @@
         <source>Exit</source>
         <translation>Выход</translation>
     </message>
+    <message>
+        <source>Camera</source>
+        <translation>Камера</translation>
+    </message>
+    <message>
+        <source>Magnification</source>
+        <translation>Лупа</translation>
+    </message>
 </context>
 <context>
     <name>cameraSettingsDialog</name>
@@ -195,35 +225,23 @@
     </message>
     <message>
         <source>Invert</source>
-        <translation>Перевернуть</translation>
+        <translation>Инвертировать</translation>
     </message>
     <message>
         <source>Gray</source>
-        <translation>Серый</translation>
+        <translation>Чёрно-белое в оттенках серого</translation>
     </message>
     <message>
         <source>Black-and-white</source>
-        <translation>Чёрно-белое</translation>
+        <translation>Чёрно-белое двухцветное</translation>
     </message>
     <message>
         <source>Remove window frame</source>
         <translation>Убрать рамку окна</translation>
     </message>
-    <message>
-        <source>160x120</source>
-        <translation>160х120</translation>
-    </message>
-    <message>
-        <source>320x240</source>
-        <translation>320х240</translation>
-    </message>
     <message>
         <source>Camera settings</source>
-        <translation>Настройки камеры</translation>
-    </message>
-    <message>
-        <source>640x480</source>
-        <translation>640х480</translation>
+        <translation>Параметры камеры</translation>
     </message>
 </context>
 <context>
@@ -258,7 +276,7 @@
     </message>
     <message>
         <source>Record Time:</source>
-        <translation>Время для записи:</translation>
+        <translation>Время записи:</translation>
     </message>
     <message>
         <source>Audio</source>
@@ -318,7 +336,7 @@
     </message>
     <message>
         <source>Videopath</source>
-        <translation>Сохранять в папке:</translation>
+        <translation>Путь к видео:</translation>
     </message>
     <message>
         <source>Limit of free disk space</source>
@@ -326,7 +344,7 @@
     </message>
     <message>
         <source>Show in systray</source>
-        <translation>Показать значок на верхней панели </translation>
+        <translation>Показывать значок в области уведомления</translation>
     </message>
     <message>
         <source>Second wait before recording</source>
@@ -382,15 +400,15 @@
     </message>
     <message>
         <source>Invert</source>
-        <translation>Перевернуть</translation>
+        <translation>Инвертировать</translation>
     </message>
     <message>
         <source>Gray</source>
-        <translation>Серый</translation>
+        <translation>Чёрно-белое в оттенках серого</translation>
     </message>
     <message>
         <source>Send Report</source>
-        <translation>Отправить жалобу</translation>
+        <translation>Отправить сообщение об ошибке</translation>
     </message>
     <message>
         <source>CTRL+SHIFT+F10</source>
@@ -406,7 +424,7 @@
     </message>
     <message>
         <source>Play last record</source>
-        <translation>Проиграть последнюю запись</translation>
+        <translation>Воспроизвести последнюю запись</translation>
     </message>
     <message>
         <source>Open folder</source>
@@ -418,7 +436,7 @@
     </message>
     <message>
         <source>Minimized when recording starts</source>
-        <translation>Сворачивать окно при начале записи</translation>
+        <translation>Сворачивать окно перед началом записи</translation>
     </message>
     <message>
         <source>Starts minimized</source>
@@ -434,7 +452,7 @@
     </message>
     <message>
         <source>Black-and-white</source>
-        <translation>Чёрно-белое</translation>
+        <translation>Чёрно-белое двухцветное</translation>
     </message>
     <message>
         <source>Remove window frame</source>
@@ -450,7 +468,7 @@
     </message>
     <message>
         <source>Copyright and license from pictures</source>
-        <translation>Копирайт и лицензия с изображений</translation>
+        <translation>Авторское право и лицензия на использование изображений</translation>
     </message>
     <message>
         <source>Megabyte</source>
@@ -458,7 +476,7 @@
     </message>
     <message>
         <source>Screencast</source>
-        <translation>Скринкаст</translation>
+        <translation>Запись с экрана</translation>
     </message>
     <message>
         <source>Player</source>
@@ -466,14 +484,50 @@
     </message>
     <message>
         <source>Log</source>
-        <translation>Логи</translation>
+        <translation>Журнал</translation>
+    </message>
+    <message>
+        <source>Automatically</source>
+        <translation>Автоматически</translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation>Создать изображения вкладок </translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation>Сведения о лицензии</translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation>Включить</translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation>Выключить</translation>
+    </message>
+    <message>
+        <source>Global keyboard shortcuts</source>
+        <translation>Глобальные комбинации клавиш</translation>
+    </message>
+    <message>
+        <source>Assigned shortcut keys.</source>
+        <translation>Назначенные комбинации клавиш.</translation>
+    </message>
+    <message>
+        <source>Keyboard shortcut not assigned or assigned more than once.</source>
+        <translation>Комбинация клавиш не назначена или назначена более одного раза.</translation>
+    </message>
+    <message>
+        <source>If it shows assigned but does not work, it is being used by another program.</source>
+        <translation>Отображение фактически не работающей комбинации клавиш в качестве использующейся означает, что она используется другой программой</translation>
     </message>
 </context>
 <context>
     <name>license</name>
     <message>
         <source>Copyright and license from pictures</source>
-        <translation>Копирайт и лицензия с изображений</translation>
+        <translation>Авторское право и лицензия на использование изображений</translation>
     </message>
 </context>
 <context>
@@ -496,7 +550,7 @@
     </message>
     <message>
         <source>Fullscreen</source>
-        <translation>Весь экран</translation>
+        <translation>Во весь экран</translation>
     </message>
     <message>
         <source>Previous frame</source>
