@@ -24,6 +24,21 @@
         <translation>Växla till helskärmsläge</translation>
     </message>
 </context>
+<context>
+    <name>QvkCiscoFinishDialog</name>
+    <message>
+        <source>The setup was successful.</source>
+        <translation>Installationen gick bra.</translation>
+    </message>
+    <message>
+        <source>Close this window and start vokoscreenNG again.</source>
+        <translation>Stäng detta fönster och starta vokoscreenNG igen.</translation>
+    </message>
+    <message>
+        <source>Have fun with vokoscreenNG</source>
+        <translation>Ha så kul med vokoscreenNG</translation>
+    </message>
+</context>
 <context>
     <name>QvkDirectSoundController</name>
     <message>
@@ -125,6 +140,13 @@
         <translation>Område</translation>
     </message>
 </context>
+<context>
+    <name>QvkRegionChoise_wl</name>
+    <message>
+        <source>Area</source>
+        <translation>Område</translation>
+    </message>
+</context>
 <context>
     <name>QvkSystray</name>
     <message>
@@ -178,6 +200,14 @@
         <source>Exit</source>
         <translation>Avsluta</translation>
     </message>
+    <message>
+        <source>Camera</source>
+        <translation>Kamera</translation>
+    </message>
+    <message>
+        <source>Magnification</source>
+        <translation>Förstoringsglas</translation>
+    </message>
 </context>
 <context>
     <name>cameraSettingsDialog</name>
@@ -209,22 +239,10 @@
         <source>Remove window frame</source>
         <translation>Ta bort fönsterram</translation>
     </message>
-    <message>
-        <source>160x120</source>
-        <translation>160x120</translation>
-    </message>
-    <message>
-        <source>320x240</source>
-        <translation>320x240</translation>
-    </message>
     <message>
         <source>Camera settings</source>
         <translation>Kamerainställningar</translation>
     </message>
-    <message>
-        <source>640x480</source>
-        <translation>640x480</translation>
-    </message>
 </context>
 <context>
     <name>formMainWindow</name>
@@ -468,6 +486,42 @@
         <source>Log</source>
         <translation>Logg</translation>
     </message>
+    <message>
+        <source>Automatically</source>
+        <translation>Automatiskt</translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation>Skapa bilder av flikar</translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation>Licensinformation</translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation>PÅ</translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation>AV</translation>
+    </message>
+    <message>
+        <source>Global keyboard shortcuts</source>
+        <translation>Systemövergripande tangentbordsgenvägar</translation>
+    </message>
+    <message>
+        <source>Assigned shortcut keys.</source>
+        <translation>Tilldelade snabbtangenter</translation>
+    </message>
+    <message>
+        <source>Keyboard shortcut not assigned or assigned more than once.</source>
+        <translation>Ej tilldelade snabbtangenter eller tilldelade mer än en gång.</translation>
+    </message>
+    <message>
+        <source>If it shows assigned but does not work, it is being used by another program.</source>
+        <translation>Om den visas som tilldelad men inte fungerar, används den av ett annat program.</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
