@@ -24,6 +24,21 @@
         <translation>Tam Ekrana Geç</translation>
     </message>
 </context>
+<context>
+    <name>QvkCiscoFinishDialog</name>
+    <message>
+        <source>The setup was successful.</source>
+        <translation>Kurulum başarılı oldu.</translation>
+    </message>
+    <message>
+        <source>Close this window and start vokoscreenNG again.</source>
+        <translation>Bu pencereyi kapatın ve vokoscreenNG&apos;yi yeniden başlatın.</translation>
+    </message>
+    <message>
+        <source>Have fun with vokoscreenNG</source>
+        <translation>vokoscreenNG ile iyi eğlenceler</translation>
+    </message>
+</context>
 <context>
     <name>QvkDirectSoundController</name>
     <message>
@@ -125,6 +140,13 @@
         <translation>Bölge</translation>
     </message>
 </context>
+<context>
+    <name>QvkRegionChoise_wl</name>
+    <message>
+        <source>Area</source>
+        <translation>Bölge</translation>
+    </message>
+</context>
 <context>
     <name>QvkSystray</name>
     <message>
@@ -178,6 +200,14 @@
         <source>Exit</source>
         <translation>Çıkış</translation>
     </message>
+    <message>
+        <source>Camera</source>
+        <translation>Kamera</translation>
+    </message>
+    <message>
+        <source>Magnification</source>
+        <translation>Büyüt</translation>
+    </message>
 </context>
 <context>
     <name>cameraSettingsDialog</name>
@@ -209,22 +239,10 @@
         <source>Remove window frame</source>
         <translation>Pencere çerçevesini kaldır</translation>
     </message>
-    <message>
-        <source>160x120</source>
-        <translation>160x120</translation>
-    </message>
-    <message>
-        <source>320x240</source>
-        <translation>320x240</translation>
-    </message>
     <message>
         <source>Camera settings</source>
         <translation>Kamera ayarları</translation>
     </message>
-    <message>
-        <source>640x480</source>
-        <translation>640x480</translation>
-    </message>
 </context>
 <context>
     <name>formMainWindow</name>
@@ -468,6 +486,42 @@
         <source>Log</source>
         <translation>Günlük</translation>
     </message>
+    <message>
+        <source>Automatically</source>
+        <translation>Otomatik olarak</translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation>Sekmelerde resim oluşturun</translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation>Lisans bilgisi</translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation>AÇ</translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation>KAPAT</translation>
+    </message>
+    <message>
+        <source>Global keyboard shortcuts</source>
+        <translation>Genel klavye kısayolları</translation>
+    </message>
+    <message>
+        <source>Assigned shortcut keys.</source>
+        <translation>Atanan kısayol tuşları.</translation>
+    </message>
+    <message>
+        <source>Keyboard shortcut not assigned or assigned more than once.</source>
+        <translation>Klavye kısayolu birden fazla atanmamış veya atanmamış.</translation>
+    </message>
+    <message>
+        <source>If it shows assigned but does not work, it is being used by another program.</source>
+        <translation>Atanmış görünüyor ancak çalışmıyorsa başka bir program tarafından kullanılıyordur.</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
