@@ -3,7 +3,7 @@
     <name>QvkAudioController</name>
     <message>
         <source>Select one or more devices</source>
-        <translation>Виберіть один або декілька пристроїв</translation>
+        <translation>Оберіть один або декілька пристроїв</translation>
     </message>
 </context>
 <context>
@@ -24,11 +24,26 @@
         <translation>Перемикнутися на повний екран</translation>
     </message>
 </context>
+<context>
+    <name>QvkCiscoFinishDialog</name>
+    <message>
+        <source>The setup was successful.</source>
+        <translation>Налаштування пройшло успішно.</translation>
+    </message>
+    <message>
+        <source>Close this window and start vokoscreenNG again.</source>
+        <translation>Закрийте це вікно та знову запустіть vokoscreenNG.</translation>
+    </message>
+    <message>
+        <source>Have fun with vokoscreenNG</source>
+        <translation>Розважайтеся з vokoscreenNG</translation>
+    </message>
+</context>
 <context>
     <name>QvkDirectSoundController</name>
     <message>
         <source>Select one or more devices</source>
-        <translation>Виберіть один або декілька пристроїв</translation>
+        <translation>Оберіть один або декілька пристроїв</translation>
     </message>
 </context>
 <context>
@@ -42,11 +57,11 @@
     <name>QvkImageFromTabs</name>
     <message>
         <source>No filemanager found.</source>
-        <translation>Файлового менеджера не знайдено.</translation>
+        <translation>Файлового упорядника не знайдено.</translation>
     </message>
     <message>
         <source>Please install a filemanager.</source>
-        <translation>Будь ласка встановіть файловий менеджер.</translation>
+        <translation>Будь ласка встановіть файловий упорядник.</translation>
     </message>
 </context>
 <context>
@@ -80,7 +95,7 @@
     <name>QvkMainWindow</name>
     <message>
         <source>Fullscreen</source>
-        <translation>Весь екран</translation>
+        <translation>Увесь екран</translation>
     </message>
     <message>
         <source>Window</source>
@@ -88,11 +103,11 @@
     </message>
     <message>
         <source>No filemanager found.</source>
-        <translation>Файлового менеджера не знайдено.</translation>
+        <translation>Файлового упорядника не знайдено.</translation>
     </message>
     <message>
         <source>Please install a filemanager.</source>
-        <translation>Будь ласка встановіть файловий менеджер.</translation>
+        <translation>Будь ласка встановіть файловий упорядник.</translation>
     </message>
     <message>
         <source>Sourcecode</source>
@@ -100,7 +115,7 @@
     </message>
     <message>
         <source>Homepage</source>
-        <translation>Веб-сайт</translation>
+        <translation>Вебсайт</translation>
     </message>
     <message>
         <source>Translations</source>
@@ -115,7 +130,7 @@
     <name>QvkPulseAudioWatcher</name>
     <message>
         <source>Select one or more devices</source>
-        <translation>Виберіть один або декілька пристроїв</translation>
+        <translation>Оберіть один або декілька пристроїв</translation>
     </message>
 </context>
 <context>
@@ -125,6 +140,13 @@
         <translation>Довільна область</translation>
     </message>
 </context>
+<context>
+    <name>QvkRegionChoise_wl</name>
+    <message>
+        <source>Area</source>
+        <translation>Довільна область</translation>
+    </message>
+</context>
 <context>
     <name>QvkSystray</name>
     <message>
@@ -178,6 +200,14 @@
         <source>Exit</source>
         <translation>Вийти</translation>
     </message>
+    <message>
+        <source>Camera</source>
+        <translation>Камера</translation>
+    </message>
+    <message>
+        <source>Magnification</source>
+        <translation>Збільшення</translation>
+    </message>
 </context>
 <context>
     <name>cameraSettingsDialog</name>
@@ -195,7 +225,7 @@
     </message>
     <message>
         <source>Invert</source>
-        <translation>Відобразити</translation>
+        <translation>Перевернути</translation>
     </message>
     <message>
         <source>Gray</source>
@@ -209,22 +239,10 @@
         <source>Remove window frame</source>
         <translation>Прибрати рамку вікна</translation>
     </message>
-    <message>
-        <source>160x120</source>
-        <translation>160x120</translation>
-    </message>
-    <message>
-        <source>320x240</source>
-        <translation>320x240</translation>
-    </message>
     <message>
         <source>Camera settings</source>
         <translation>Налаштування камери</translation>
     </message>
-    <message>
-        <source>640x480</source>
-        <translation>640x480</translation>
-    </message>
 </context>
 <context>
     <name>formMainWindow</name>
@@ -278,7 +296,7 @@
     </message>
     <message>
         <source>Audiocodec</source>
-        <translation>Аудіокодек</translation>
+        <translation>Авдіокодек</translation>
     </message>
     <message>
         <source>Quality</source>
@@ -286,7 +304,7 @@
     </message>
     <message>
         <source>Do not record mouse cursor</source>
-        <translation>Не записувати курсор миші</translation>
+        <translation>Не записувати вказівник миші</translation>
     </message>
     <message>
         <source>Hour</source>
@@ -318,7 +336,7 @@
     </message>
     <message>
         <source>Videopath</source>
-        <translation>Зберегти в теку</translation>
+        <translation>Зберегти до теки</translation>
     </message>
     <message>
         <source>Limit of free disk space</source>
@@ -374,7 +392,7 @@
     </message>
     <message>
         <source>Folder</source>
-        <translation>Папка</translation>
+        <translation>Тека</translation>
     </message>
     <message>
         <source>Camera</source>
@@ -382,7 +400,7 @@
     </message>
     <message>
         <source>Invert</source>
-        <translation>Відобразити</translation>
+        <translation>Перевернути</translation>
     </message>
     <message>
         <source>Gray</source>
@@ -468,6 +486,42 @@
         <source>Log</source>
         <translation>Лог</translation>
     </message>
+    <message>
+        <source>Automatically</source>
+        <translation>Автоматично</translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation>Створення зображень вкладок</translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation>Інформація про ліцензію</translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation>УВІМК</translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation>ВИМК</translation>
+    </message>
+    <message>
+        <source>Global keyboard shortcuts</source>
+        <translation>Глобальні клавішні скорочення</translation>
+    </message>
+    <message>
+        <source>Assigned shortcut keys.</source>
+        <translation>Призначені клавіші швидкого доступу.</translation>
+    </message>
+    <message>
+        <source>Keyboard shortcut not assigned or assigned more than once.</source>
+        <translation>Скорочення клавішів не призначено або призначено більше одного разу.</translation>
+    </message>
+    <message>
+        <source>If it shows assigned but does not work, it is being used by another program.</source>
+        <translation>Якщо показує призначено, але не працює, то використовується іншою програмою.</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
@@ -496,7 +550,7 @@
     </message>
     <message>
         <source>Fullscreen</source>
-        <translation>Весь екран</translation>
+        <translation>Увесь екран</translation>
     </message>
     <message>
         <source>Previous frame</source>
