@@ -24,6 +24,21 @@
         <translation>切换至全屏</translation>
     </message>
 </context>
+<context>
+    <name>QvkCiscoFinishDialog</name>
+    <message>
+        <source>The setup was successful.</source>
+        <translation>设置成功</translation>
+    </message>
+    <message>
+        <source>Close this window and start vokoscreenNG again.</source>
+        <translation>关闭这个窗口并且重新启动vokoscreenNG</translation>
+    </message>
+    <message>
+        <source>Have fun with vokoscreenNG</source>
+        <translation>vokoscreenNG祝你玩得开心</translation>
+    </message>
+</context>
 <context>
     <name>QvkDirectSoundController</name>
     <message>
@@ -88,7 +103,7 @@
     </message>
     <message>
         <source>No filemanager found.</source>
-        <translation>未发现文件管理器。</translation>
+        <translation>未发现文件管理器</translation>
     </message>
     <message>
         <source>Please install a filemanager.</source>
@@ -125,6 +140,13 @@
         <translation>区域</translation>
     </message>
 </context>
+<context>
+    <name>QvkRegionChoise_wl</name>
+    <message>
+        <source>Area</source>
+        <translation>区域</translation>
+    </message>
+</context>
 <context>
     <name>QvkSystray</name>
     <message>
@@ -178,6 +200,14 @@
         <source>Exit</source>
         <translation>退出</translation>
     </message>
+    <message>
+        <source>Camera</source>
+        <translation>摄像头</translation>
+    </message>
+    <message>
+        <source>Magnification</source>
+        <translation>放大</translation>
+    </message>
 </context>
 <context>
     <name>cameraSettingsDialog</name>
@@ -209,22 +239,10 @@
         <source>Remove window frame</source>
         <translation>移除窗口边框</translation>
     </message>
-    <message>
-        <source>160x120</source>
-        <translation>160x120</translation>
-    </message>
-    <message>
-        <source>320x240</source>
-        <translation>320x240</translation>
-    </message>
     <message>
         <source>Camera settings</source>
         <translation>摄像头设置</translation>
     </message>
-    <message>
-        <source>640x480</source>
-        <translation>640x480</translation>
-    </message>
 </context>
 <context>
     <name>formMainWindow</name>
@@ -406,7 +424,7 @@
     </message>
     <message>
         <source>Play last record</source>
-        <translation>播放最新一次的录制</translation>
+        <translation>播放最后一次的录制</translation>
     </message>
     <message>
         <source>Open folder</source>
@@ -468,6 +486,42 @@
         <source>Log</source>
         <translation>日志</translation>
     </message>
+    <message>
+        <source>Automatically</source>
+        <translation>自动</translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation>创建标签图像</translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation>许可证信息</translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation>开</translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation>关</translation>
+    </message>
+    <message>
+        <source>Global keyboard shortcuts</source>
+        <translation>全局键盘快捷键</translation>
+    </message>
+    <message>
+        <source>Assigned shortcut keys.</source>
+        <translation>指定快捷键</translation>
+    </message>
+    <message>
+        <source>Keyboard shortcut not assigned or assigned more than once.</source>
+        <translation>键盘快捷键未指定或者重复</translation>
+    </message>
+    <message>
+        <source>If it shows assigned but does not work, it is being used by another program.</source>
+        <translation>如果已指定但是不工作，意味着其它程序已使用</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
