@@ -2,7 +2,7 @@
  * Copyright (C) 2017-2019 Volker Kohaupt
  * 
  * Author:
- *      Volker Kohaupt <vkohaupt@freenet.de>
+ *      Volker Kohaupt <vkohaupt@volkoh.de>
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of version 2 of the GNU General Public License
@@ -20,7 +20,8 @@
  * --End_License--
  */
 
-#include "QvkLog.h" 
+#include "QvkLog.h"
+#include "global.h"
 
 #include <QDebug>
 #include <QStandardPaths>
@@ -30,7 +31,7 @@
 QvkLog::QvkLog()
 {
     QDateTime dateTime = QDateTime::currentDateTime();
-    QString stringDateTime = dateTime.toString( "yyyy_MM_dd_hh_mm_ss" );
+    QString stringDateTime = dateTime.toString( "yyyy-MM-dd_hh-mm-ss" );
     path = QStandardPaths::writableLocation( QStandardPaths::AppConfigLocation );
 
     QString logFolderName = path + "/" + "log";
@@ -50,8 +51,15 @@ QvkLog::~QvkLog()
 
 void QvkLog::outputMessage( QtMsgType type, const QMessageLogContext &context, const QString &msg )
 {
+    // Insert timestamp
+    QString sTime = QTime::currentTime().toString();
+    QString sMsg( msg );
+    if ( !sMsg.isEmpty() ) {
+        sMsg.prepend( sTime + " " ) ;
+    }
+
     // Output terminal
-    QByteArray localMsg = msg.toLocal8Bit();
+    QByteArray localMsg = sMsg.toLocal8Bit();
     switch (type) {
     case QtDebugMsg:
         fprintf( stderr, "%s\n", localMsg.constData() );
@@ -77,11 +85,11 @@ void QvkLog::outputMessage( QtMsgType type, const QMessageLogContext &context, c
 #ifdef Q_OS_WIN
     QString eol = "\r\n";
 #endif
-    logFile.open( QIODevice::Append | QIODevice::Text | QIODevice::Unbuffered );
-    logFile.write( msg.toUtf8() );
-    logFile.write( eol.toUtf8() );
+    logFile.open( QIODevice::WriteOnly | QIODevice::Append );
+    QTextStream stream( &logFile );
+    stream << sMsg << eol;
     logFile.close();
 
     // Output GUI
-    emit signal_newLogText( msg );
+    emit signal_newLogText( sMsg );
 }
