@@ -1,8 +1,8 @@
-/* vokoscreenNG - A desktop recorder
+﻿/* vokoscreenNG - A desktop recorder
  * Copyright (C) 2017-2019 Volker Kohaupt
  * 
  * Author:
- *      Volker Kohaupt <vkohaupt@freenet.de>
+ *      Volker Kohaupt <vkohaupt@volkoh.de>
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of version 2 of the GNU General Public License
@@ -30,6 +30,7 @@
 #include "QvkLicenses.h"
 #include "QvkImageFromTabs.h"
 #include "QvkDirDialog.h"
+#include "QvkVirtual.h"
 
 #include <QDebug>
 #include <QDateTime>
@@ -189,8 +190,6 @@ QvkMainWindow::QvkMainWindow(QWidget *parent) : QMainWindow(parent),
     vkMagnifierController = new QvkMagnifierController(ui);
     Q_UNUSED(vkMagnifierController);
 
-    vkPlayer = new QvkPlayer( this, ui );
-
     QvkHelp *vkHelp = new QvkHelp( ui );
 
     QvkLicenses *vkLicenses = new QvkLicenses( ui );
@@ -200,6 +199,7 @@ QvkMainWindow::QvkMainWindow(QWidget *parent) : QMainWindow(parent),
     vkCountdown = new QvkCountdown();
     vkCountdown->init();
 
+    QvkVirtual *vkVirtual = new QvkVirtual();
 
     QvkInformation *vkInformation = new QvkInformation( this, ui, sliderScreencastCountDown, sliderSecondWaitBeforeRecording );
     connect( this, SIGNAL( signal_newVideoFilename( QString ) ), vkInformation, SLOT( slot_newVideoFilename( QString ) ) );
@@ -217,18 +217,19 @@ QvkMainWindow::QvkMainWindow(QWidget *parent) : QMainWindow(parent),
 #ifdef Q_OS_LINUX
     qDebug().noquote() << global::nameOutput << "PulseAudio library version:" << pa_get_library_version();
 #endif
+    qDebug().noquote() << global::nameOutput << "Virtual Maschine:" << vkVirtual->isVirtualMaschine();
     qDebug().noquote() << global::nameOutput << "Operating system:" << QSysInfo::prettyProductName();
     qDebug().noquote() << global::nameOutput << "KernelVersion:"  << QSysInfo::kernelVersion();
     qDebug().noquote() << global::nameOutput << "CPU Architecture:" << QSysInfo::currentCpuArchitecture();
     qDebug().noquote() << global::nameOutput << "Count CPU:" << QThread::idealThreadCount();
     qDebug().noquote() << global::nameOutput << global::name << "running as:" << QGuiApplication::platformName() << "client";
-
 #ifdef Q_OS_LINUX
     qDebug().noquote() << global::nameOutput << global::name << "running on:" << qgetenv( "XDG_SESSION_TYPE" ).toLower();
 #endif
     qDebug().noquote() << global::nameOutput << "Desktop:" << qgetenv( "XDG_CURRENT_DESKTOP" );
     qDebug().noquote() << global::nameOutput << "Icon-Theme:" << QIcon::themeName();
-    qDebug().noquote() << global::nameOutput << "Styles:" << QStyleFactory::keys();
+    qDebug().noquote() << global::nameOutput << "Styles:" << QApplication::style()->metaObject()->className();
+    qDebug().noquote() << global::nameOutput << "InstallPath:        " << QCoreApplication::applicationDirPath();
     qDebug().noquote() << global::nameOutput << "Qt-PluginsPath:     " << QLibraryInfo::location( QLibraryInfo::PluginsPath );
     qDebug().noquote() << global::nameOutput << "Qt-TranslationsPath:" << QLibraryInfo::location( QLibraryInfo::TranslationsPath );
     qDebug().noquote() << global::nameOutput << "Qt-LibraryPath:     " << QLibraryInfo::location( QLibraryInfo::LibrariesPath );
@@ -257,6 +258,18 @@ QvkMainWindow::QvkMainWindow(QWidget *parent) : QMainWindow(parent),
 
     vk_setCornerWidget( ui->tabWidgetScreencast );
 
+// Linux player deactivated to manny errrors
+/*
+#ifdef Q_OS_LINUX
+    vkPlayer = new QvkPlayer( ui );
+#endif
+#ifdef Q_OS_WIN
+    vkPlayer = new QvkPlayer( this, ui );
+#endif
+*/
+    vkPlayer = new QvkPlayer( this, ui );
+
+
     // Sidebar
     connect( ui->toolButtonScreencast, &QToolButton::clicked, this, [=]() { ui->tabWidgetSideBar->setCurrentIndex(0); } );
     connect( ui->toolButtonCamera,     &QToolButton::clicked, this, [=]() { ui->tabWidgetSideBar->setCurrentIndex(1); } );
@@ -375,7 +388,6 @@ QvkMainWindow::QvkMainWindow(QWidget *parent) : QMainWindow(parent),
     connect( ui->radioButtonScreencastWindow, SIGNAL( toggled( bool ) ), ui->comboBoxScreencastScreenArea, SLOT( setDisabled( bool ) ) );
     connect( ui->radioButtonScreencastWindow, SIGNAL( toggled( bool ) ), ui->toolButtonScreencastAreaReset, SLOT( setDisabled( bool ) ) );
 
-    connect( this,                            SIGNAL( signal_close()  ), vkRegionChoise, SLOT( close() ) );
     connect( ui->radioButtonScreencastArea,   SIGNAL( toggled( bool ) ), vkRegionChoise, SLOT( slot_init() ) );
     connect( ui->radioButtonScreencastArea,   SIGNAL( toggled( bool ) ), vkRegionChoise, SLOT( setVisible( bool ) ) );
     connect( ui->radioButtonScreencastArea,   SIGNAL( toggled( bool ) ), ui->comboBoxScreencastScreen, SLOT( setDisabled( bool ) ) );
@@ -433,21 +445,45 @@ QvkMainWindow::QvkMainWindow(QWidget *parent) : QMainWindow(parent),
     // ***************** Begin showClick *****************************
     vkShowClick = new QvkShowClick();
     vkShowClick->init( ui );
+    vk_setCornerWidget( ui->tabWidgetShowClick );
+
     // ***************** End showClick
 
     vkHalo = new QvkHalo();
     vkHalo->init( ui );
 
+    /* Wayland
+     * If start with "./name -platform wayland" comes a Memory access error
+     * On Wayland we have to time no access to GlobalShortcuts
+     * We must disable this function for Wayland but not for X11 and Windows
+     */
+#ifdef Q_OS_LINUX
+    if ( QX11Info::isPlatformX11() == true )
+    {
+        vkGlobalShortcut = new QvkGlobalShortcut( this, ui );
+        Q_UNUSED(vkGlobalShortcut);
+    }
+#endif
+#ifdef Q_OS_WIN
+    vkGlobalShortcut = new QvkGlobalShortcut( this, ui );
+    Q_UNUSED(vkGlobalShortcut);
+#endif
+    vk_setCornerWidget( ui->tabWidgetShortcut );
 
     vkSystrayAlternative = new QvkSystrayAlternative( this, ui, sliderShowInSystrayAlternative );
     if ( QSystemTrayIcon::isSystemTrayAvailable() == true )
     {
-        connect( ui->checkBoxShowInSystray, SIGNAL( clicked( bool ) ), this, SLOT( slot_setVisibleSystray( bool ) ) );
+        vkSystray = new QvkSystray(ui);
+        vkSystray->init();
+        connect( vkSystray,                 SIGNAL( signal_SystemtrayIsClose() ),                 this,      SLOT( close() ) );
+        connect( ui->checkBoxShowInSystray, SIGNAL( clicked( bool ) ),                            vkSystray, SLOT( setVisible( bool ) ) );
+        connect( vkGlobalShortcut,          SIGNAL( signal_shortcutSystray( QString, QString ) ), vkSystray, SLOT( slot_shortcutSystray( QString, QString ) ) );
         ui->frameShowInSystrayAlternative->hide();
         ui->toolButtonShowInSystrayAlternativeReset->hide();
     } else
     {
         connect( ui->checkBoxShowInSystrayAlternative, SIGNAL( clicked( bool ) ), vkSystrayAlternative, SLOT( setVisible( bool ) ) );
+        connect( vkGlobalShortcut,          SIGNAL( signal_shortcutSystray( QString, QString ) ), vkSystrayAlternative, SLOT( slot_shortcutSystray( QString, QString ) ) );
         ui->frameShowInSystray->hide();
     }
 
@@ -474,6 +510,8 @@ QvkMainWindow::QvkMainWindow(QWidget *parent) : QMainWindow(parent),
     connect( this,      SIGNAL( signal_close() ),       vkHelp,                 SLOT( close() ) );
     connect( this,      SIGNAL( signal_close() ),       vkLicenses,             SLOT( close() ) );
     connect( this,      SIGNAL( signal_close() ),       vkSystrayAlternative,   SLOT( close() ) );
+    connect( this,      SIGNAL( signal_close() ),       vkPlayer,               SLOT( close() ) );
+    connect( this,      SIGNAL( signal_close() ),       vkRegionChoise,         SLOT( close() ) );
 
     VK_Supported_Formats_And_Codecs();
     VK_Check_is_Format_available();
@@ -503,26 +541,6 @@ QvkMainWindow::QvkMainWindow(QWidget *parent) : QMainWindow(parent),
     connect( ui->pushButtonSendReport, SIGNAL( clicked( bool ) ), this, SLOT( slot_sendReport() ) );
     // *****************End Log ***********************************
 
-
-    /* Wayland
-     * If start with "./name -platform wayland" comes a Memory access error
-     * On Wayland we have to time no access to GlobalShortcuts
-     * We must disable this function for Wayland but not for X11 and Windows
-     */
-#ifdef Q_OS_LINUX
-    if ( QX11Info::isPlatformX11() == true )
-    {
-        vkGlobalShortcut = new QvkGlobalShortcut( this, ui );
-        Q_UNUSED(vkGlobalShortcut);
-    }
-#endif
-#ifdef Q_OS_WIN
-    vkGlobalShortcut = new QvkGlobalShortcut( this, ui );
-    Q_UNUSED(vkGlobalShortcut);
-#endif
-    vk_setCornerWidget( ui->tabWidgetShortcut );
-
-
 #ifdef Q_OS_WIN
     vkCiscoOpenh264Controller = new QvkCiscoOpenh264Controller( vkSettings.getFileName(), ui );
     vkCiscoOpenh264Controller->showWaitDialog();
@@ -560,6 +578,8 @@ QvkMainWindow::QvkMainWindow(QWidget *parent) : QMainWindow(parent),
 
     QvkImageFromTabs *vkImageFromTabs = new QvkImageFromTabs( this );
     vkImageFromTabs->init( ui );
+
+    have_video_folder_write_permission();
 }
 
 
@@ -569,6 +589,54 @@ QvkMainWindow::~QvkMainWindow()
 }
 
 
+bool QvkMainWindow::have_video_folder_write_permission()
+{
+    QString filename;
+    if ( vkSettings.getVideoPath() > "" ) {
+        filename = vkSettings.getVideoPath() + + "/vokoscreenNG-test-write.txt";
+    } else {
+        filename = QStandardPaths::writableLocation( QStandardPaths::MoviesLocation ) + "/vokoscreenNG-test-write.txt";
+    }
+
+    bool value;
+    QFileInfo fileInfo( filename );
+    QFile file( filename );
+    if ( file.open( QIODevice::ReadWrite ) )
+    {
+        QTextStream stream( &file );
+        stream << "Test Test Test Test Test Test" << Qt::endl;
+        file.close();
+        qDebug().noquote();
+        qDebug().noquote() << global::nameOutput << "Permission: Can write in" << fileInfo.absolutePath();
+        qDebug().noquote();
+        file.remove();
+        value = true;
+    } else {
+        qDebug().noquote();
+        qDebug().noquote() << "Permission: ERROR can not write in" << fileInfo.absolutePath();
+        qDebug().noquote();
+        QMessageBox *messageBox = new QMessageBox();
+        QIcon icon( QString::fromUtf8( ":/pictures/logo/logo.png" ) );
+        messageBox->setWindowIcon( icon );
+        messageBox->setWindowTitle( global::name + " " + global::version );
+        messageBox->setIcon( QMessageBox::Critical );
+        messageBox->setTextFormat( Qt::RichText );
+        messageBox->setText( ( "<b>No write access on video folder</b>" ) );
+        messageBox->setInformativeText( "vokoscreenNG can not create a video on<br>" + \
+                                        fileInfo.absolutePath() + "<br><br>" + \
+                                        "<b>Possible reasons:</b><br>" +
+                                        "1. The folder is read-only<br>" +
+                                        "2. Operating system security settings<br>" +
+                                        "3. Antivirus program prevents writing<br><br>" +
+                                        "<b>Please fix the problem and restart vokoscreenNG<b>"
+                                       );
+        messageBox->exec();
+        value = false;
+    }
+    return value;
+}
+
+
 void QvkMainWindow::slot_haveAudioDeviceSelected( bool bo )
 {
     if ( bo == false ) {
@@ -628,12 +696,6 @@ void QvkMainWindow::closeEvent( QCloseEvent *event )
 }
 
 
-void QvkMainWindow::slot_vokoPlayer()
-{
-    vkPlayer->show();
-}
-
-
 /*
  * CountDown
  */
@@ -730,7 +792,7 @@ void QvkMainWindow::slot_sendReport()
 #endif
     QStringList stringList;
     stringList << "mailto:";
-    stringList << "vkohaupt@freenet.de";
+    stringList << "vkohaupt@volkoh.de";
     stringList << "?";
     stringList << "subject=";
     stringList << QString( global::name + QString( " " ) +  global::version );
@@ -771,24 +833,6 @@ void QvkMainWindow::slot_sendReport()
 }
 
 
-void QvkMainWindow::slot_setVisibleSystray( bool value )
-{
-    if ( value == false )
-    {
-        vkSystray->slot_closeSystray();
-        delete vkSystray;
-    }
-
-    if ( value == true )
-    {
-        vkSystray = new QvkSystray(ui);
-        vkSystray->init();
-        connect( vkSystray, SIGNAL( signal_SystemtrayIsClose() ), this,      SLOT( close() ) );
-        connect( this,      SIGNAL( signal_close() ),             vkSystray, SLOT( slot_closeSystray() ) );
-    }
-}
-
-
 void QvkMainWindow::slot_IfStartAudioCodecWidgetsSetEnabled()
 {
     if ( isAudioDeviceSelected() == true )
@@ -892,6 +936,38 @@ void QvkMainWindow::resizeEvent( QResizeEvent *event )
 }
 
 
+// Linux player deactivated to manny errors
+/*
+#ifdef Q_OS_LINUX
+void QvkMainWindow::mouseDoubleClickEvent( QMouseEvent *event )
+{
+    Q_UNUSED(event)
+
+    // Doubleclick in empty playergui
+    if ( vkPlayer->isFullScreen() == true ){
+        vkPlayer->widgetsToGui();
+        return;
+    }
+
+    if ( ( vkPlayer->vkPlayerGst->is_running() == true ) or ( vkPlayer->vkPlayerGst->is_pause() == true ) )
+    {
+        vkPlayer->widgetsToPlayer();
+        vkPlayer->showFullScreen();
+    }
+}
+
+
+void QvkMainWindow::keyPressEvent( QKeyEvent *event )
+{
+    // Player go from GUI to Fullscreen
+    if ( ( event->key() == Qt::Key_F11 ) or ( event->key() == Qt::Key_F ) ) {
+        vkPlayer->widgetsToPlayer();
+        vkPlayer->showFullScreen();
+    }
+}
+#endif
+*/
+
 void QvkMainWindow::vk_setCornerWidget( QTabWidget *tabWidget )
 {
 #ifdef Q_OS_LINUX
@@ -1392,7 +1468,7 @@ void QvkMainWindow::VK_Supported_Formats_And_Codecs()
 
 void QvkMainWindow::VK_Check_is_Format_available()
 {
-    qDebug().noquote() << global::nameOutput << "Symbols: + available, - not available";
+    qDebug().noquote() << global::nameOutput << "Record symbols: + available, - not available";
     QStringList tempList;
     for ( int x = 0; x < videoFormatsList.count(); x++ )
     {
@@ -1588,6 +1664,19 @@ void QvkMainWindow::slot_preStart()
         ui->lineEditVideoPath->setText( QStandardPaths::writableLocation( QStandardPaths::MoviesLocation ) );
     }
 
+
+    if ( have_video_folder_write_permission() == false )
+    {
+        ui->pushButtonStop->setEnabled( false );
+        ui->pushButtonStart->setEnabled( true );
+        ui->pushButtonPause->setEnabled( false );
+        ui->pushButtonPlay->setEnabled( false );
+        ui->checkBoxResetAtNextStart->setChecked( true );
+        ui->checkBoxResetAtNextStart->setEnabled( false );
+        return;
+    }
+
+
     if ( vkLimitDiskFreeSpace->isStorageOKMessagBoxByStart() == false )
     {
         wantRecording = false;
@@ -1739,6 +1828,21 @@ QString QvkMainWindow::VK_getMuxer()
 }
 
 
+QStringList QvkMainWindow::VK_getSelectedAudioDeviceName()
+{
+    QStringList list;
+    QList<QCheckBox *> listQCheckBox = ui->scrollAreaWidgetContentsAudioDevices->findChildren<QCheckBox *>();
+    for ( int i = 0; i < listQCheckBox.count(); i++ )
+    {
+        if ( listQCheckBox.at(i)->checkState() == Qt::Checked )
+        {
+            list << listQCheckBox.at(i)->text();
+        }
+    }
+    return list;
+}
+
+
 QStringList QvkMainWindow::VK_getSelectedAudioDevice()
 {
     QStringList list;
@@ -1802,7 +1906,8 @@ void QvkMainWindow::slot_Start()
     if ( ( VK_getSelectedAudioDevice().count() == 1 ) and ( ui->comboBoxAudioCodec->count() > 0 ) )
     {
         #ifdef Q_OS_LINUX
-            VK_PipelineList << VK_get_AudioSystem().append( " device=" ).append( VK_getSelectedAudioDevice().at(0) );
+            VK_PipelineList << VK_get_AudioSystem().append( " device=" ).append( VK_getSelectedAudioDevice().at(0) )
+                                                   .append( " client-name=" ).append( global::nameOutput + "." + QString( VK_getSelectedAudioDeviceName().at(0) ).replace( " ", "-") );
             VK_PipelineList << "audio/x-raw, channels=2";
             VK_PipelineList << "audioconvert";
             VK_PipelineList << "audiorate";
@@ -1855,23 +1960,25 @@ void QvkMainWindow::slot_Start()
         for ( int x = 0; x < VK_getSelectedAudioDevice().count(); x++ )
         {
             #ifdef Q_OS_LINUX
-                VK_PipelineList << VK_get_AudioSystem().append( " device=" ).append( VK_getSelectedAudioDevice().at(x) );
-                VK_PipelineList << "audio/x-raw, channels=2";
+                VK_PipelineList << VK_get_AudioSystem().append( " device=" ).append( VK_getSelectedAudioDevice().at(x) )
+                                                       .append( " client-name=" ).append( global::nameOutput + "." + QString( VK_getSelectedAudioDeviceName().at(x) ).replace( " ", "-") );
+                VK_PipelineList << "audioconvert";
                 VK_PipelineList << "queue";
                 VK_PipelineList << "mix.";
             #endif
 
             #ifdef Q_OS_WIN
-                if ( vkAudioController->radioButtonDirectSound->isCheckable() )
+                if ( vkAudioController->radioButtonDirectSound->isChecked() )
                 {
                     VK_PipelineList << QString( "directsoundsrc device-name=" ).append( "'" + VK_getSelectedAudioDevice().at(x) + "'" );
-                    VK_PipelineList << "audio/x-raw, channels=2";
+                    VK_PipelineList << "audioconvert";
                     VK_PipelineList << "queue";
                     VK_PipelineList << "mix.";
                 }
             #endif
         }
         VK_PipelineList << "audiomixer name=mix";
+        VK_PipelineList << "audio/x-raw, channels=2";
         VK_PipelineList << "audioconvert";
         VK_PipelineList << "audiorate";
         VK_PipelineList << "queue";
@@ -1893,11 +2000,11 @@ void QvkMainWindow::slot_Start()
     VK_Pipeline = VK_Pipeline.replace( "mix. !", "mix." );
     VK_Pipeline = VK_Pipeline.replace( "mux. !", "mux." );
 
-    qDebug( " " );
+    qDebug();
     qDebug().noquote() << global::nameOutput << "Free disk space at the beginning of the recording:" << ui->labelFreeSize->text() << "MB";
-    qDebug( " " );
+    qDebug();
     qDebug().noquote() << global::nameOutput << "Start record with:" << VK_Pipeline;
-    qDebug( " " );
+    qDebug();
     qDebug().noquote() << Pipeline_structured_output( VK_Pipeline );
 
     QByteArray byteArray = VK_Pipeline.toUtf8();
@@ -2049,7 +2156,7 @@ void QvkMainWindow::slot_Play()
     filters << global::name + "*";
     QStringList videoFileList = dir.entryList( filters, QDir::Files, QDir::Time );
 
-    qDebug().noquote() << global::nameOutput << "play video with vokoplayer";
+    qDebug().noquote() << global::nameOutput << "play video with vokoplayer" << videoFileList.at(0);
     ui->toolButtonPlayer->click();
     QString string;
     string.append( ui->lineEditVideoPath->text() );
@@ -2059,6 +2166,7 @@ void QvkMainWindow::slot_Play()
     vkPlayer->slot_play();
 }
 
+
 void QvkMainWindow::slot_Folder()
 {
     if ( QDesktopServices::openUrl( QUrl( "file:///" + ui->lineEditVideoPath->text(), QUrl::TolerantMode ) ) == false )
