@@ -2,7 +2,7 @@
  * Copyright (C) 2017-2019 Volker Kohaupt
  * 
  * Author:
- *      Volker Kohaupt <vkohaupt@freenet.de>
+ *      Volker Kohaupt <vkohaupt@volkoh.de>
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of version 2 of the GNU General Public License
@@ -48,7 +48,6 @@
 #include <QFileSystemWatcher>
 #include <QSoundEffect>
 #include <QShowEvent>
-//#include <QWindow>
 
 #include <gst/gst.h>
 
@@ -75,6 +74,7 @@ public:
     QvkMagnifierController *vkMagnifierController;
     QvkGlobalShortcut *vkGlobalShortcut;
 
+
 private:
     QvkShowClick *vkShowClick;
 
@@ -113,6 +113,7 @@ private:
     void VK_set_available_Formats_in_Combox();
     QString VK_get_AudioSystem();
     QStringList VK_getSelectedAudioDevice();
+    QStringList VK_getSelectedAudioDeviceName();
 
 
     QString get_x_From_Screen();
@@ -146,10 +147,14 @@ private:
 
     bool cancel = false;
 
+    bool have_video_folder_write_permission();
+
 #ifdef Q_OS_WIN
     QvkCiscoOpenh264Controller *vkCiscoOpenh264Controller;
 #endif
 
+    QPalette appPalette;
+
 
 private slots:
     void slot_textToGuiLog( QString value );
@@ -185,12 +190,8 @@ private slots:
     void slot_IfStartAudioCodecWidgetsSetEnabled();
     void slot_IfStopAudioCodecWidgetsSetDisabled();
 
-    void slot_setVisibleSystray( bool value );
-
     void slot_sendReport();
 
-    void slot_vokoPlayer();
-
     void slot_setMaxFPS( int );
 
     void slot_gst_formatVideoAudoicodec_available();
@@ -211,6 +212,13 @@ protected:
     void closeEvent( QCloseEvent *event );
     void resizeEvent( QResizeEvent *event );
 
+// New linux player deactivtaed to manny errors
+/*
+#ifdef Q_OS_LINUX
+    void mouseDoubleClickEvent( QMouseEvent *event );
+    void keyPressEvent( QKeyEvent *event );
+#endif
+*/
 
 };
 
