@@ -2,7 +2,7 @@
  * Copyright (C) 2017-2019 Volker Kohaupt
  * 
  * Author:
- *      Volker Kohaupt <vkohaupt@freenet.de>
+ *      Volker Kohaupt <vkohaupt@volkoh.de>
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of version 2 of the GNU General Public License
@@ -203,6 +203,13 @@ void QvkSettings::readAll( Ui_formMainWindow *ui_mainwindow, QMainWindow *parent
             listCheckBox.at(i)->click();
             continue;
         }
+        if ( ( listCheckBox.at(i)->objectName() == "checkBoxShowInSystray" ) and
+             ( settings.value( listCheckBox.at(i)->objectName(), true ).toBool() == false ) )
+        {
+            listCheckBox.at(i)->click();
+            listCheckBox.at(i)->click();
+            continue;
+        }
 
         if ( ( listCheckBox.at(i)->objectName() == "checkBoxStartsMinimized" ) and
              ( settings.value( listCheckBox.at(i)->objectName(), false ).toBool() == true ) )
@@ -342,23 +349,6 @@ void QvkSettings::readAll( Ui_formMainWindow *ui_mainwindow, QMainWindow *parent
         }
 
         QVariant variant = settings.value( listSlider.at(i)->objectName() );
-
-        if ( listSlider.at(i)->objectName() == "sliderCameraWindowSize" )
-        {
-            if ( variant.isValid() )
-            {
-                listSlider.at(i)->setValue( variant.toInt() );
-                listSlider.at(i)->setMinimum(1);
-                continue;
-            }
-            else
-            {
-                listSlider.at(i)->setValue(2);
-                listSlider.at(i)->setMinimum(1);
-                continue;
-            }
-        }
-
         if ( variant.isValid() )
         {
             listSlider.at(i)->setValue( variant.toInt() );
