@@ -2,7 +2,7 @@
  * Copyright (C) 2017-2019 Volker Kohaupt
  * 
  * Author:
- *      Volker Kohaupt <vkohaupt@freenet.de>
+ *      Volker Kohaupt <vkohaupt@volkoh.de>
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of version 2 of the GNU General Public License
@@ -245,3 +245,73 @@ void QvkSystray::slot_currentIndexChanged( int index )
     else
         cameraAction->setEnabled( false );
 }
+
+
+void QvkSystray::slot_shortcutSystray( QString device, QString shortcut )
+{
+    if ( device == "Start" ){
+        startAction->setShortcutVisibleInContextMenu( true );
+        startAction->setShortcut( QKeySequence::fromString( shortcut ) );
+        if ( shortcut == "None" ){
+            startAction->setShortcutVisibleInContextMenu( false );
+        }
+        return;
+    }
+
+    if ( device == "Stop" ){
+        stopAction->setShortcutVisibleInContextMenu( true );
+        stopAction->setShortcut( QKeySequence::fromString( shortcut ) );
+        if ( shortcut == "None" ){
+            stopAction->setShortcutVisibleInContextMenu( false );
+        }
+    }
+
+    if ( device == "Pause" ){
+        pauseAction->setShortcutVisibleInContextMenu( true );
+        pauseAction->setShortcut( QKeySequence::fromString( shortcut ) );
+        if ( shortcut == "None" ){
+            pauseAction->setShortcutVisibleInContextMenu( false );
+        }
+    }
+
+    if ( device == "Continue" ){
+        continueAction->setShortcutVisibleInContextMenu( true );
+        continueAction->setShortcut( QKeySequence::fromString( shortcut ) );
+        if ( shortcut == "None" ){
+            continueAction->setShortcutVisibleInContextMenu( false );
+        }
+    }
+
+    if ( device == "camera" ){
+        cameraAction->setShortcutVisibleInContextMenu( true );
+        cameraAction->setShortcut( QKeySequence::fromString( shortcut ) );
+        if ( shortcut == "None" ){
+            cameraAction->setShortcutVisibleInContextMenu( false );
+        }
+    }
+
+    if ( device == "magnification" ){
+        magnifierAction->setShortcutVisibleInContextMenu( true );
+        magnifierAction->setShortcut( QKeySequence::fromString( shortcut ) );
+        if ( shortcut == "None" ){
+            magnifierAction->setShortcutVisibleInContextMenu( false );
+        }
+    }
+
+    if ( device == "showclick" ){
+        showclickAction->setShortcutVisibleInContextMenu( true );
+        showclickAction->setShortcut( QKeySequence::fromString( shortcut ) );
+        if ( shortcut == "None" ){
+            showclickAction->setShortcutVisibleInContextMenu( false );
+        }
+    }
+
+    if ( device == "halo" ){
+        haloAction->setShortcutVisibleInContextMenu( true );
+        haloAction->setShortcut( QKeySequence::fromString( shortcut ) );
+        if ( shortcut == "None" ){
+            haloAction->setShortcutVisibleInContextMenu( false );
+        }
+    }
+
+}
