@@ -2,7 +2,7 @@
  * Copyright (C) 2017-2019 Volker Kohaupt
  * 
  * Author:
- *      Volker Kohaupt <vkohaupt@freenet.de>
+ *      Volker Kohaupt <vkohaupt@volkoh.de>
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of version 2 of the GNU General Public License
@@ -71,6 +71,11 @@ private slots:
 
     void slot_currentIndexChanged( int index );
 
+    void slot_shortcutSystray( QString device, QString shortcut );
+
+
+
+
 protected:
   
   
