@@ -26,6 +26,21 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>QvkCiscoFinishDialog</name>
+    <message>
+        <source>The setup was successful.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Close this window and start vokoscreenNG again.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Have fun with vokoscreenNG</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>QvkDirectSoundController</name>
     <message>
@@ -127,6 +142,13 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>QvkRegionChoise_wl</name>
+    <message>
+        <source>Area</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>QvkSystray</name>
     <message>
@@ -180,6 +202,14 @@
         <source>Exit</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Camera</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Magnification</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>cameraSettingsDialog</name>
@@ -211,22 +241,10 @@
         <source>Remove window frame</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>160x120</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>320x240</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Camera settings</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>640x480</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>formMainWindow</name>
@@ -470,6 +488,42 @@
         <source>Log</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Automatically</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Global keyboard shortcuts</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Assigned shortcut keys.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Keyboard shortcut not assigned or assigned more than once.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>If it shows assigned but does not work, it is being used by another program.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>license</name>
