@@ -2,7 +2,7 @@
  * Copyright (C) 2017-2019 Volker Kohaupt
  * 
  * Author:
- *      Volker Kohaupt <vkohaupt@freenet.de>
+ *      Volker Kohaupt <vkohaupt@volkoh.de>
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of version 2 of the GNU General Public License
@@ -21,17 +21,17 @@
  */
 
 #include "QvkRegionChoise_wl.h"
-#include "QvkRegionButtonArrow_wl.h"
+#include "QvkRegionButtonArrow.h"
 #include "global.h"
 
 #include <QDebug>
 #include <QPainter>
+#include <QGuiApplication>
 #include <QBitmap>
 #include <QPaintEvent>
 #include <QIcon>
-#include <QTimer>
 
-QvkRegionChoise_wl::QvkRegionChoise_wl():handlePressed(NoHandle),
+QvkRegionChoise_wl::QvkRegionChoise_wl( Ui_formMainWindow_wl *ui_formMainWindow ):handlePressed(NoHandle),
                                    handleUnderMouse(NoHandle),
                                    HandleColorBackground( Qt::lightGray ),
                                    HandleColorBackgroundSize( Qt::lightGray ),
@@ -52,58 +52,30 @@ QvkRegionChoise_wl::QvkRegionChoise_wl():handlePressed(NoHandle),
                                    frameColor(Qt::lightGray)
 {
 
-//    setWindowTitle( QString( tr( "Area") ) );
-    setWindowTitle( QString( ( "Area") ) );
+    ui = ui_formMainWindow;
+
+    setWindowTitle( QString( tr( "Area") ) );
 
     QIcon icon;
     icon.addFile( QString::fromUtf8( ":/pictures/logo/logo.png" ), QSize(), QIcon::Normal, QIcon::Off );
     setWindowIcon( icon );
 
-    setWindowFlags( Qt::FramelessWindowHint );
-    setAttribute( Qt::WA_TranslucentBackground, true );
+    // Hint: Qt::WindowStaysOnTopHint is only for X11 and Windows on WayLand not do it
+    setWindowFlags( Qt::FramelessWindowHint | Qt::WindowStaysOnTopHint | Qt::ToolTip ); // With Qt::ToolTip no keyboard;
+    setAttribute( Qt::WA_TranslucentBackground, true);
     setMouseTracking( true );
     setFrameColor( Qt::darkGreen );
-    hide();
 }
 
 
-/*
- * bool value = true radiobutton was selected
- * bool value = false radio button was deselected
- */
-void QvkRegionChoise_wl::slot_show( bool value )
+void QvkRegionChoise_wl::slot_init()
 {
-    // Hinweis:
-    // Die Bereichsanzeige ist ein Fenster und wird immmer am beginn des verfügbaren Bereichs auf dem Desktop gesetzt.
-    // Ist das Desktop-Panel oben am Bildschirm wird das Fenster z.b bei 0,44 gesetzt.
-    // Ist das Panel unten am Bildschirm wird das Fenster bei 0,0 gesetzt.
-    // Die Frage ist, wie erkennt man ob das Desktop-Panel oben oder unten gesetzt ist?
-    // Gelöst wird das bis jetzt in dem der User in der GUI angeben muß wo das Panel plaziert ist
 
-
-    // Das Fenster wird dort plaziert wo sich die GUI befindet, dies wird vom compositer geregelt.
-    // Damit die Fenstergröße ermittelt werden kann ist unter KDE folgender ablauf zwingend notwendig
-    // Gnome wurde getestet und funktioniert.
-    if ( value == true )
-    {
-        // "Screen" wird im weiteren Verlauf noch gebraucht für pixelratio
-        Screen = screen();
-
-        // Das Fenster wird per "show()" in einer von Qt vorgegebenen größe angezeigt
-        // Anschließend wird das Fenster per "singelshot()" maximiert
-        show();
-        update();
-        QTimer::singleShot( 1000, Qt::PreciseTimer, this, SLOT( showMaximized() ) );
-        update();
-    } else
-    {
-        // Beim ausblenden muß das Fenster erst per "shownormal()" dargestellt werden
-        // und anschließend per "hide()" versteckt werden
-        showNormal();
-        update();
-        QTimer::singleShot( 1000, Qt::PreciseTimer, this, SLOT( hide() ) );
-        update();
-    }
+    QList<QScreen *> screenList = QGuiApplication::screens();
+    screen = screenList.at( 0 );
+    resize( screen->size().width(), screen->size().height() );
+    screenWidth = screen->size().width();
+    screenHeight = screen->size().height();
 }
 
 
@@ -112,25 +84,6 @@ QvkRegionChoise_wl::~QvkRegionChoise_wl()
 }
 
 
-// Ermitteln der größten Fensterhöhe und breite zwischen den Panels
-void QvkRegionChoise_wl::resizeEvent(QResizeEvent *event)
-{
-    Q_UNUSED(event);
-    windowWidth = size().width();
-    windowHeight = size().height();
-}
-
-
-/*
- * Panel is the desktop panel that contain the Taskbar, Systray and other things.
- */
-int QvkRegionChoise_wl::get_sum_all_panels_height()
-{
-    return ( Screen->size().height() - size().height() );
-}
-
-
-
 void QvkRegionChoise_wl::setHandleColorBackground( QColor color )
 {
     HandleColorBackground = color;
@@ -158,7 +111,6 @@ void QvkRegionChoise_wl::vk_setGeometry( int x, int y, int with, int height  )
   frame_Y = y;
   frame_Width = with;
   frame_height = height;
-  update();
 }
 
 
@@ -166,7 +118,7 @@ void QvkRegionChoise_wl::paintEvent( QPaintEvent *event )
 {
     (void)event;
 
-    QPixmap pixmap( windowWidth, windowHeight );
+    QPixmap pixmap( screenWidth, screenHeight );
 
     if ( recordemode == false )
     {
@@ -299,9 +251,7 @@ void QvkRegionChoise_wl::mousePressEvent(QMouseEvent *event)
     old_Frame_X2 = frame_X + frame_Width;
     old_Frame_Y2 = frame_Y + frame_height;
 
-    clearMask();
-    update();
-
+    repaint();
 }
 
 
@@ -314,7 +264,9 @@ void QvkRegionChoise_wl::mouseReleaseEvent( QMouseEvent * event )
 
   handlePressed = NoHandle;
 
-  update();
+  repaint();
+  setVisible( false );
+  setVisible( true );
 }
 
 
@@ -459,7 +411,7 @@ void QvkRegionChoise_wl::keyPressEvent( QKeyEvent * event )
             case Qt::Key_Right :{
                                    frame_Width = frame_Width + 1;
 
-                                   if ( ( frame_X + frame_Width - framePenHalf ) > windowWidth )
+                                   if ( ( frame_X + frame_Width - framePenHalf ) > screenWidth )
                                    {
                                        frame_Width = frame_Width - 1;
                                    }
@@ -486,7 +438,7 @@ void QvkRegionChoise_wl::keyPressEvent( QKeyEvent * event )
             case Qt::Key_Right :{
                                    frame_Width = frame_Width + 1;
 
-                                   if ( ( frame_X + frame_Width - framePenHalf ) > windowWidth )
+                                   if ( ( frame_X + frame_Width - framePenHalf ) > screenWidth )
                                    {
                                        frame_Width = frame_Width - 1;
                                    }
@@ -513,7 +465,7 @@ void QvkRegionChoise_wl::keyPressEvent( QKeyEvent * event )
             case Qt::Key_Down : {
                                    frame_height = frame_height + 1;
 
-                                   if ( frame_Y + frame_height - framePenHalf > windowHeight )
+                                   if ( frame_Y + frame_height - framePenHalf > screenHeight )
                                    {
                                        frame_height = frame_height - 1;
                                    }
@@ -533,7 +485,7 @@ void QvkRegionChoise_wl::keyPressEvent( QKeyEvent * event )
             case Qt::Key_Right :{
                                    frame_Width = frame_Width + 1;
 
-                                   if ( frame_X + frame_Width - framePenHalf > windowWidth )
+                                   if ( frame_X + frame_Width - framePenHalf > screenWidth )
                                    {
                                        frame_Width = frame_Width - 1;
                                    }
@@ -560,7 +512,7 @@ void QvkRegionChoise_wl::keyPressEvent( QKeyEvent * event )
             case Qt::Key_Down : {
                                    frame_height = frame_height + 1;
 
-                                   if ( frame_Y + frame_height - framePenHalf > windowHeight )
+                                   if ( frame_Y + frame_height - framePenHalf > screenHeight )
                                    {
                                        frame_height = frame_height - 1;
                                    }
@@ -587,7 +539,7 @@ void QvkRegionChoise_wl::keyPressEvent( QKeyEvent * event )
             case Qt::Key_Down :  {
                                     frame_height = frame_height + 1;
 
-                                    if ( frame_Y + frame_height - framePenHalf > windowHeight )
+                                    if ( frame_Y + frame_height - framePenHalf > screenHeight )
                                     {
                                         frame_height = frame_height - 1;
                                     }
@@ -669,7 +621,7 @@ void QvkRegionChoise_wl::keyPressEvent( QKeyEvent * event )
             case Qt::Key_Right : {
                                     frame_X = frame_X + 1;
 
-                                    if ( frame_X + frame_Width - framePenHalf > windowWidth )
+                                    if ( frame_X + frame_Width - framePenHalf > screenWidth )
                                     {
                                         frame_X = frame_X - 1;
                                     }
@@ -689,7 +641,7 @@ void QvkRegionChoise_wl::keyPressEvent( QKeyEvent * event )
             case Qt::Key_Down  : {
                                     frame_Y = frame_Y + 1;
 
-                                    if ( frame_Y + frame_height - framePenHalf > windowHeight )
+                                    if ( frame_Y + frame_height - framePenHalf > screenHeight )
                                     {
                                         frame_Y = frame_Y - 1;
                                     }
@@ -700,7 +652,6 @@ void QvkRegionChoise_wl::keyPressEvent( QKeyEvent * event )
     }
 
     repaint();
-    update();
 }
 
 
@@ -790,9 +741,9 @@ void QvkRegionChoise_wl::mouseMoveEvent( QMouseEvent *event )
                              frame_height = old_Frame_Y2 + framePenHalf;
                            }
 
-                           if( ( frame_X + frame_Width - framePenHalf ) > windowWidth )
+                           if( ( frame_X + frame_Width - framePenHalf ) > screenWidth )
                            {
-                             frame_Width = windowWidth + framePenHalf - frame_X;
+                             frame_Width = screenWidth + framePenHalf - frame_X;
                            }
 
                            break;
@@ -807,9 +758,9 @@ void QvkRegionChoise_wl::mouseMoveEvent( QMouseEvent *event )
                            }
 
                            // Limit max
-                           if( ( frame_X + frame_Width - framePenHalf ) > windowWidth )
+                           if( ( frame_X + frame_Width - framePenHalf ) > screenWidth )
                            {
-                             frame_Width = windowWidth + framePenHalf - frame_X;
+                             frame_Width = screenWidth + framePenHalf - frame_X;
                            }
 
                            break;
@@ -830,14 +781,14 @@ void QvkRegionChoise_wl::mouseMoveEvent( QMouseEvent *event )
                            }
 
                            //Limit max
-                           if( ( frame_X + frame_Width - framePenHalf ) > windowWidth )
+                           if( ( frame_X + frame_Width - framePenHalf ) > screenWidth )
                            {
-                             frame_Width = windowWidth + framePenHalf - frame_X;
+                             frame_Width = screenWidth + framePenHalf - frame_X;
                            }
 
-                           if( ( frame_Y + frame_height - framePenHalf ) > windowHeight )
+                           if( ( frame_Y + frame_height - framePenHalf ) > screenHeight )
                            {
-                             frame_height = windowHeight + framePenHalf - frame_Y;
+                             frame_height = screenHeight + framePenHalf - frame_Y;
                            }
 
                            break;
@@ -852,9 +803,9 @@ void QvkRegionChoise_wl::mouseMoveEvent( QMouseEvent *event )
                            }
 
                            //Limit max
-                           if( ( frame_Y + frame_height - framePenHalf ) > windowHeight )
+                           if( ( frame_Y + frame_height - framePenHalf ) > screenHeight )
                            {
-                             frame_height = windowHeight + framePenHalf - frame_Y;
+                             frame_height = screenHeight + framePenHalf - frame_Y;
                            }
 
                            break;
@@ -884,9 +835,9 @@ void QvkRegionChoise_wl::mouseMoveEvent( QMouseEvent *event )
                               frame_Width = old_Frame_X2 + framePenHalf;
                            }
 
-                           if( ( frame_Y + frame_height - framePenHalf ) > windowHeight )
+                           if( ( frame_Y + frame_height - framePenHalf ) > screenHeight )
                            {
-                             frame_height = windowHeight + framePenHalf - frame_Y;
+                             frame_height = screenHeight + framePenHalf - frame_Y;
                            }
 
                            break;
@@ -930,28 +881,27 @@ void QvkRegionChoise_wl::mouseMoveEvent( QMouseEvent *event )
                            }
 
                            // Limit Right
-                           if( ( frame_X + frame_Width - framePenHalf ) > windowWidth )
+                           if( ( frame_X + frame_Width - framePenHalf ) > screenWidth )
                            {
-                               frame_X = windowWidth - frame_Width + framePenHalf;
+                               frame_X = screenWidth - frame_Width + framePenHalf;
                            }
 
                            // Limit Bottom
-                           if( ( frame_Y + frame_height - framePenHalf ) > windowHeight )
+                           if( ( frame_Y + frame_height - framePenHalf ) > screenHeight )
                            {
-                               frame_Y = windowHeight - frame_height + framePenHalf;
+                               frame_Y = screenHeight - frame_height + framePenHalf;
                            }
 
                            break;
                          }
     } // end switch
 
+
     if ( handlePressed != NoHandle )
     {
-            clearMask();
-            update();
+            repaint();
     }
 
-
     if ( handlePressed != NoHandle )
         return;
 
@@ -1005,7 +955,7 @@ void QvkRegionChoise_wl::mouseMoveEvent( QMouseEvent *event )
         return;
     }
 
-    QvkRegionButtonArrow_wl buttonArrow;
+    QvkRegionButtonArrow buttonArrow;
     QRect regionBottomRight( frame_X + frame_Width - buttonArrow.getWithHalf(),
                                frame_Y + frame_height - buttonArrow.getWithHalf(),
                                buttonArrow.getWithHalf()*2,
@@ -1069,9 +1019,9 @@ void QvkRegionChoise_wl::mouseMoveEvent( QMouseEvent *event )
 
 void QvkRegionChoise_wl::printSize( QPainter &painter )
 {
-  QString widthHeigtSize = QString::number( static_cast<int>( getWidthRecordArea()/Screen->devicePixelRatio() ) ) +
+  QString widthHeigtSize = QString::number( static_cast<int>( getWidth()/screen->devicePixelRatio() ) ) +
                            " x " +
-                           QString::number( static_cast<int>( getHeightRecordArea()/Screen->devicePixelRatio() ) );
+                           QString::number( static_cast<int>( getHeight()/screen->devicePixelRatio() ) );
 
   QFont font;
   font.setPointSize( 14 );
@@ -1141,7 +1091,7 @@ void QvkRegionChoise_wl::HandleRecord( QPainter &painter, int x, int y, int star
 
 void QvkRegionChoise_wl::HandleTopLeft( QPainter &painter )
 {
-    QvkRegionButtonArrow_wl buttonArrow;
+    QvkRegionButtonArrow buttonArrow;
     QColor color;
 
     if ( handlePressed == TopLeft )
@@ -1198,7 +1148,7 @@ void QvkRegionChoise_wl::HandleTopLeftSize( QPainter &painter)
 
 void QvkRegionChoise_wl::HandleTopMiddle( QPainter &painter)
 {
-    QvkRegionButtonArrow_wl buttonArrow;
+    QvkRegionButtonArrow buttonArrow;
     QColor color;
 
     if ( handlePressed == TopMiddle )
@@ -1253,7 +1203,7 @@ void QvkRegionChoise_wl::HandleTopMiddleSize( QPainter &painter )
 
 void QvkRegionChoise_wl::HandleTopRight(QPainter &painter)
 {
-    QvkRegionButtonArrow_wl buttonArrow;
+    QvkRegionButtonArrow buttonArrow;
     QColor color;
 
     if ( handlePressed == TopRight )
@@ -1310,7 +1260,7 @@ void QvkRegionChoise_wl::HandleTopRightSize( QPainter &painter )
 
 void QvkRegionChoise_wl::HandleRightMiddle( QPainter &painter )
 {
-    QvkRegionButtonArrow_wl buttonArrow;
+    QvkRegionButtonArrow buttonArrow;
     QColor color;
 
     if ( handlePressed == RightMiddle )
@@ -1365,7 +1315,7 @@ void QvkRegionChoise_wl::HandleRightMiddleSize( QPainter &painter )
 
 void QvkRegionChoise_wl::HandleBottomRight( QPainter &painter )
 {
-    QvkRegionButtonArrow_wl buttonArrow;
+    QvkRegionButtonArrow buttonArrow;
     QColor color;
 
     if ( handlePressed == BottomRight )
@@ -1395,7 +1345,7 @@ void QvkRegionChoise_wl::HandleBottomRight( QPainter &painter )
 
 void QvkRegionChoise_wl::HandleBottomRightSize( QPainter &painter )
 {
-    QvkRegionButtonArrow_wl buttonArrow;
+    QvkRegionButtonArrow buttonArrow;
     QFont font;
     font.setPointSize( 10 );
     painter.setFont( font );
@@ -1424,7 +1374,7 @@ void QvkRegionChoise_wl::HandleBottomRightSize( QPainter &painter )
 
 void QvkRegionChoise_wl::HandleBottomMiddle( QPainter &painter )
 {
-    QvkRegionButtonArrow_wl buttonArrow;
+    QvkRegionButtonArrow buttonArrow;
     QColor color;
 
     if ( handlePressed == BottomMiddle )
@@ -1479,7 +1429,7 @@ void QvkRegionChoise_wl::HandleBottomMiddleSize(QPainter &painter )
 
 void QvkRegionChoise_wl::HandleBottomLeft( QPainter &painter )
 {
-    QvkRegionButtonArrow_wl buttonArrow;
+    QvkRegionButtonArrow buttonArrow;
     QColor color;
 
     if ( handlePressed == BottomLeft )
@@ -1536,7 +1486,7 @@ void QvkRegionChoise_wl::HandleBottomLeftSize( QPainter &painter )
 
 void QvkRegionChoise_wl::HandleLeftMiddle( QPainter &painter )
 {
-    QvkRegionButtonArrow_wl buttonArrow;
+    QvkRegionButtonArrow buttonArrow;
     QColor color;
 
     if ( handlePressed == LeftMiddle )
@@ -1592,7 +1542,7 @@ void QvkRegionChoise_wl::HandleLeftMiddleSize( QPainter &painter )
 
 void QvkRegionChoise_wl::HandleMiddle( QPainter &painter )
 {
-    QvkRegionButtonArrow_wl buttonArrow;
+    QvkRegionButtonArrow buttonArrow;
     QColor color;
 
     if ( handlePressed == Middle )
@@ -1642,13 +1592,11 @@ void QvkRegionChoise_wl::recordMode( bool value )
     {
         recordemode = true;
         repaint();
-        update();
     }
     else
     {
         recordemode = false;
         repaint();
-        update();
     }
 }
 
@@ -1675,8 +1623,8 @@ int QvkRegionChoise_wl::getY()
  */
 qreal QvkRegionChoise_wl::getXRecordArea()
 {
-    qreal xReal = ( frame_X + framePenWidth/2 ) * Screen->devicePixelRatio();
-    int xInt = static_cast<int>( ( frame_X + framePenWidth/2 ) * Screen->devicePixelRatio() );
+    qreal xReal = ( frame_X + framePenWidth/2 ) * screen->devicePixelRatio();
+    int xInt = static_cast<int>( ( frame_X + framePenWidth/2 ) * screen->devicePixelRatio() );
 
     if ( xReal > xInt )
     {
@@ -1692,8 +1640,8 @@ qreal QvkRegionChoise_wl::getXRecordArea()
  */
 qreal QvkRegionChoise_wl::getYRecordArea()
 {
-   qreal xReal = ( frame_Y + framePenWidth/2 ) * Screen->devicePixelRatio();
-   int xInt = static_cast<int>( ( frame_Y + framePenWidth/2 ) * Screen->devicePixelRatio() );
+   qreal xReal = ( frame_Y + framePenWidth/2 ) * screen->devicePixelRatio();
+   int xInt = static_cast<int>( ( frame_Y + framePenWidth/2 ) * screen->devicePixelRatio() );
 
    if ( xReal > xInt )
    {
@@ -1707,18 +1655,18 @@ qreal QvkRegionChoise_wl::getYRecordArea()
 /**
  * Return height from record area
  */
-qreal QvkRegionChoise_wl::getHeightRecordArea()
+qreal QvkRegionChoise_wl::getHeight()
 {
-    qreal xReal =   ( ( frame_Y + framePenWidth/2 ) + ( frame_height - framePenWidth ) ) * Screen->devicePixelRatio();
-    int xInt = static_cast<int>( ( ( frame_Y + framePenWidth/2 ) + ( frame_height - framePenWidth ) ) * Screen->devicePixelRatio() );
+    qreal xReal =   ( ( frame_Y + framePenWidth/2 ) + ( frame_height - framePenWidth ) ) * screen->devicePixelRatio();
+    int xInt = static_cast<int>( ( ( frame_Y + framePenWidth/2 ) + ( frame_height - framePenWidth ) ) * screen->devicePixelRatio() );
 
     if ( xReal > xInt )
     {
-        xReal = static_cast<int>( ( frame_height - framePenWidth ) * Screen->devicePixelRatio() ) - 1;
+        xReal = static_cast<int>( ( frame_height - framePenWidth ) * screen->devicePixelRatio() ) - 1;
     }
     else
     {
-        xReal = static_cast<int>( ( frame_height - framePenWidth ) * Screen->devicePixelRatio() );
+        xReal = static_cast<int>( ( frame_height - framePenWidth ) * screen->devicePixelRatio() );
     }
 
     return xReal;
@@ -1728,18 +1676,18 @@ qreal QvkRegionChoise_wl::getHeightRecordArea()
 /**
  * Return width from record Area
  */
-qreal QvkRegionChoise_wl::getWidthRecordArea()
+qreal QvkRegionChoise_wl::getWidth()
 {
-    qreal xReal = ( ( frame_X + framePenWidth/2 ) + ( frame_Width - framePenWidth ) ) * Screen->devicePixelRatio();
-    int xInt = static_cast<int>( ( ( frame_X + framePenWidth/2 ) + ( frame_Width - framePenWidth ) ) * Screen->devicePixelRatio() );
+    qreal xReal = ( ( frame_X + framePenWidth/2 ) + ( frame_Width - framePenWidth ) ) * screen->devicePixelRatio();
+    int xInt = static_cast<int>( ( ( frame_X + framePenWidth/2 ) + ( frame_Width - framePenWidth ) ) * screen->devicePixelRatio() );
 
     if ( xReal > xInt )
     {
-        xReal = static_cast<int>( ( frame_Width - framePenWidth ) * Screen->devicePixelRatio() ) - 1;
+        xReal = static_cast<int>( ( frame_Width - framePenWidth ) * screen->devicePixelRatio() ) - 1;
     }
     else
     {
-        xReal = static_cast<int>( ( frame_Width - framePenWidth ) * Screen->devicePixelRatio() );
+        xReal = static_cast<int>( ( frame_Width - framePenWidth ) * screen->devicePixelRatio() );
     }
 
     return xReal;
@@ -1753,21 +1701,18 @@ void QvkRegionChoise_wl::slot_areaReset()
     frame_Width = frame_min_width;
     frame_height = frame_min_height;
     repaint();
-    update();
 }
 
 void QvkRegionChoise_wl::setX( int x )
 {
     frame_X = x - framePenHalf;
     repaint();
-    update();
 }
 
 void QvkRegionChoise_wl::setY( int y )
 {
     frame_Y = y - framePenHalf;
     repaint();
-    update();
 }
 
 
@@ -1775,13 +1720,11 @@ void QvkRegionChoise_wl::setWidth( int width )
 {
     frame_Width = width + framePenWidth;
     repaint();
-    update();
 }
 
 void QvkRegionChoise_wl::setHeight( int height )
 {
     frame_height = height + framePenWidth;
     repaint();
-    update();
 }
 
